
*WAVE 2 CRAM
*FILE PURPOSE: Pre-Analysis, Post-first clean file for analysis of the CRAM DATA 
* Also merges in our Wave 1 NIDS-CRAM data, which includes NIDS Wave 5 data
*TABLES AND FIGURES 

clear all
set more off, permanent
set maxvar 25000
capture log close
set scheme plotplain

if c(username)=="Ronak" {
	global cram "C:\Users\ronhi\Dropbox (Harvard University)\CRAM paper\"
	global trash "C:\Users\ronhi\Desktop\cram\"
}
if c(username)=="ihsaa" {
	global cram "C:\Users\ihsaa\Dropbox\CRAM paper"
	global cram_w2  "C:\Users\ihsaa\Dropbox\CRAM paper\Wave 2" 
	global trash "C:\Users\ihsaa\Documents\Data"
}

if c(username)=="joshb" {
	global cram "C:\Users\joshb\Dropbox\projects\CRAM paper"
	global cram_w2 "C:\Users\joshb\Dropbox\projects\CRAM paper\Wave 2"
	global trash "C:\Users\joshb\Desktop\inbox"
}

* decide whether we want to run the extra pre-tests
local extra_pretests no

//COLOR CODING
global emp1 "green %70"
global emp2 "gold %70"
global emp3 "orange %70"
global emp4 "maroon %90"



***************************************************************
*Quick merge
***************************************************************

//Wave 6 (7064 obs)
// NOTE TO REPLICATORS: SEE OUR POSTED WAVE 1 DO-FILES FOR THESE .DTA AND .DO FILES
use "${cram}\Data\Data\w5_nc_v1.dta", clear
do "${cram}\do files\main_clean.do"	// IF YOU ARE USING OUR INTERNAL FILES, THIS IS CALLED cleaningfile_all_v1
drop if nids_sample==.
keep w6_totwage* w6_empcat* w6_age w6_gender w6_area w6_occu w5_a_em1contr ///
	w6_race w6_wgt w6_educ_bins pid w5_hhincomepc~4 w6_emdays_feb~p w6_emdays_apr~p ///
	w6_hhincloss_main  w6_metro cover_grnt_unemp cover_grnt_ters ///
	w6_hhfdyn jobloss_* w6_hhsizer w6_hhincome w5_formal w5_hhincome w5_hhq_inc ///
	w6_hhincome w6_hhincome_cl w6_hhincome_imp w6_guess_hhid w5_hhsizer w6_prov ///
	w5_prov w6_dc2011 w5_dc2011 w6_hhincloss_any w5_hhincomepc w6_csg_number ///
	w6_oap_number w5_hhdependents w6_eminc_feb w6_fdcyn_imp w6_fdayn_imp w6_eminc_apr ///
	w6_eminc_apr w6_emsinc_apr  w5_gender w5_area w5_empl_stat w5_occu w5_race w5_educ_bins w5_age w6_outcome w6_empl_stat 

ren (cover_grnt_unemp cover_grnt_ters) (w6_cover_grnt_unemp w6_cover_grnt_ters)
save "$trash\tempw6.dta", replace




//Wave 7 (5676 obs)
do "${cram_w2}\Do files\w2_prep_clean.do" // IF YOU ARE USING UPLOADED FILES, THIS IS CALLED w2_cleaningfile_all.do
keep if w7_outcome==1
keep w7_totwage* w7_empcat* w7_age w7_gender w7_area w7_occu w7_race w7_educ_bins pid w7_emdays_* w7_hhincloss_main cover_grnt_unemp cover_grnt_ters w7_hhfdyn w7_hhsizer w7_hhincome w7_hhincome_cl w7_hhincome_imp w7_prov w7_dc2011 w7_csg_number w7_srd_number  w7_eminc_jun_imp w7_emsinc_jun_imp w7_oap_number w7_fdcyn_imp w7_fdayn_imp fwgt cluster stratum w7_hhsrd w7_ind_inccovid w7_ind_incchld w7_ind_incgovpen w7_ind_incdis cover_srd_unemp  cover_uif_unemp  w7_incvgrt  cover_indsrd_unemp w7_hhincome_lb w7_hhincome_lb_cl w7_hhincome_noimp_cl w7_outcome w7_empl_stat

ren (cover_grnt_ters) (w7_cover_grnt_ters)


//Merge (all matched from wave 7)
merge 1:1 pid using "$trash\tempw6.dta"
keep if _merge==3
drop _merge

numlabel, add
g w7_fwgt= round(fwgt)
/*Attrition adjustment
The following explanatory variables were included in the 
final probit model – race, sex, age categories (<30, 30-39, 40-50, >50), 
province3, urban location, an indicator that household income was 
missing, an indicator that the individual was employed 
at the time of the Wave 1 interview and 
NIDS Wave 5 household per capita income quartiles.
*/
save "$trash\temp.dta", replace




***************************************************************
*SETUP TO KEEP HERE
***************************************************************

use "$trash\temp.dta", clear 


//Keep only working age pop (deletes 10%)
keep if inrange(w6_age, 18,64)


//Adult chars as defined in w6

*Youth 
g youth= w6_age<=35 if w6_age<=55
g female= w6_gender==2 if w6_gender!=.

*Race (exclude indian)
g black= inlist(w6_race,1,2) if w6_race!=. & w6_race!=3

*Tertiary vs others
g tertiary= w6_educ_bins==4 if w6_educ_bins!=.
g nontertiary= tertiary==0 if tertiary!=.

g age2=w6_age^2


*group q1 and q2 together for het 
g w5_hhincomepc_cat= 1 if w5_hhincomepc_q4==1 | w5_hhincomepc_q4==2
replace w5_hhincomepc_cat= 2 if w5_hhincomepc_q4==3
replace w5_hhincomepc_cat= 3 if w5_hhincomepc_q4==4

g poor= w5_hhincomepc_cat==1 if w5_hhincomepc_cat!=.


*quartiles of feb earnings
g earn_feb_con= w6_totwage_feb if w6_totwage_feb>0 & w6_totwage_feb!=.
xtile earn_feb_conq= earn_feb_con [aw=w6_wgt], n(4)
recode earn_feb_conq (1 2=1)(3=2)(4=3)



//Adult chars defined in other years

g urban= w7_area==2 if w7_area!=.

*Informal 2017
g  contract= w5_formal==1 if w5_formal!=.
g noncontract= contract==0 if contract!=.



//Emp dummies
cap drop empfeb? empapr? empjun?
tab w6_empcat_feb if w6_empcat_feb!=., gen(empfeb)
tab w6_empcat_apr if w6_empcat_apr!=., gen(empapr) 
tab w7_empcat_jun if w6_empcat_apr!=., gen(empjun) 



foreach i of numlist 6 7 {

	//Occupations
	recode w`i'_occu (1/3= 1 "Professionals")(4/8= 2 "Service/Operators") (9= 3 "Manual")(*=.), gen(w`i'_occupcat)
	g w`i'_manual= (w`i'_occupcat==3) if w`i'_occupcat!=.


	//HHincome (use without outliers)
	*pc
	g w`i'_hhincomepc= w`i'_hhincome_cl/w`i'_hhsizer
	g w`i'_lnhhincomepc= ln(w`i'_hhincomepc)

	*poverty
	g w`i'_foodpov= w`i'_hhincomepc<436 if w`i'_hhincomepc!=.
	g w`i'_ubpov= w`i'_hhincomepc<1265 if w`i'_hhincomepc!=.
	
}

//Job loss
gen w6_jobloss_34 = 0 if w6_empcat_feb==1
replace w6_jobloss_34 = 1 if inlist(w6_empcat_apr, 3,4) & w6_empcat_feb==1
gen w7_jobloss_34 = 0 if w6_empcat_feb==1
replace w7_jobloss_34 = 1 if inlist(w7_empcat_jun, 3,4) & w6_empcat_feb==1


//Grants poverty for wave 7

* w/o SRD
g hhsrdamt= 350*w7_srd_number
replace hhsrdamt= 0 if hhsrdamt==.
g w7_hhincomepc_nosrd= (w7_hhincome_cl - hhsrdamt)/w7_hhsizer
replace w7_hhincomepc_nosrd= 0 if w7_hhincomepc_nosrd<0

g foodpov_nosrd= w7_hhincomepc_nosrd<436 if w7_hhincomepc_nosrd!=.
g ubpov_nosrd= w7_hhincomepc_nosrd<1265 if w7_hhincomepc_nosrd!=.





// HH=hincome response weights

cap drop w6_hhinc_respond agecatnids

* create vars
gen w6_hhinc_respond = !mi(w6_hhincome_cl)
recode w7_age (0/29 = 1) (30/39 = 2) (40/50 = 3) (50/max = 4) , gen(agecatnids)

*adding missings to avoid losing vars
foreach var in w7_race w7_gender agecatnids w7_prov urban empapr1 w5_hhincomepc_q4 {
	g `var'nomiss= `var'
	replace `var'nomiss= 999 if `var'==.
}

* logit as per sampling document
logit w6_hhinc_respond i.w7_racenomiss i.w7_gendernomiss i.agecatnidsnomiss i.w7_provnomiss i.urbannomiss i.empapr1nomiss  i.w5_hhincomepc_q4nomiss 

* create pscore and IPW, check how it looks
cap drop pscore
predict pscore
cap drop invpw
gen invpw = 1/pscore
su invpw,d		
// looks completely ok to me... largest value is 2*median, though is a notable right tail as densities show (looks less dramatic for pscore as opposed to invpw). 
	// kdensity invpw
	// twoway (kdensity invpw if w6_hhinc_respond == 0) (kdensity invpw if w6_hhinc_respond == 1), legend(order(1 "missing w6inc" 2 "has w6inc"))
	// twoway (kdensity pscore if w6_hhinc_respond == 0) (kdensity pscore if w6_hhinc_respond == 1), legend(order(1 "missing w6inc" 2 "has w6inc"))

* create final weight
cap drop incwt
gen incwt = round(w7_fwgt * invpw)


numlabel, add
compress
save "${trash}\temp.dta", replace




***************************************************************
*PRE-TESTS 
***************************************************************
if "${extra_pretests}" == "yes" {

use "${trash}\temp.dta", clear


// URBAN/RURAL checks****************************
lab var w7_area "w7 geotype"
lab var w6_area "w6 geotype"

tab w7_area [fw=w7_fwgt], m
tab w6_area [fw=w7_fwgt], m

tab w6_area w7_area [fw=w7_fwgt], m row
tab w6_area w7_area, m row


// EARNINGS****************************

egen rawjun = rowtotal(w7_eminc_jun w7_emsinc_jun)
replace rawjun = . if rawjun == 0
egen rawapr = rowtotal(w6_eminc_apr w6_emsinc_apr)
replace rawapr = . if rawapr == 0
gen rawfeb = w6_eminc_feb
replace rawfeb = . if rawfeb == 0

foreach var in rawjun rawapr rawfeb {
	cap drop ln_`var'
	gen ln_`var' = ln(`var')
}

* feb - apr
// twoway (kdensity ln_rawfeb)  (kdensity ln_rawapr)  if !mi(ln_rawfeb) & !mi(ln_rawapr) 
// graph export "${cram_w2}\Figures\extra_diagnostics\earn_febapr_nw.png", replace
// twoway (kdensity ln_rawfeb [aw=w7_fwgt])  (kdensity ln_rawapr [aw=w7_fwgt])  if !mi(ln_rawfeb) & !mi(ln_rawapr) 
// graph export "${cram_w2}\Figures\extra_diagnostics\earn_febapr_yw.png", replace

gen chg_febapr = (rawapr-rawfeb)/rawfeb

* feb - june 
// twoway (kdensity ln_rawfeb)  (kdensity ln_rawjun)  if !mi(ln_rawfeb) & !mi(ln_rawjun) 
// graph export "${cram_w2}\Figures\extra_diagnostics\earn_febjun_nw.png", replace
// twoway (kdensity ln_rawfeb [aw=w7_fwgt])  (kdensity ln_rawjun [aw=w7_fwgt])  if !mi(ln_rawfeb) & !mi(ln_rawjun) 
// graph export "${cram_w2}\Figures\extra_diagnostics\earn_febjun_yw.png", replace

gen chg_febjun = (rawjun-rawfeb)/rawfeb

* apr - june 
// twoway (kdensity ln_rawapr)  (kdensity ln_rawjun)  if !mi(ln_rawapr) & !mi(ln_rawjun) 
// graph export "${cram_w2}\Figures\extra_diagnostics\earn_aprjun_nw.png", replace
// twoway (kdensity ln_rawapr [aw=w7_fwgt])  (kdensity ln_rawjun [aw=w7_fwgt])  if !mi(ln_rawapr) & !mi(ln_rawjun) 
//graph export "${cram_w2}\Figures\extra_diagnostics\earn_aprjun_yw.png", replace

gen chg_aprjun = (rawjun-rawapr)/rawapr

** median change and below is really similar across all. but for jun version we have >100% (or >200%) increases by 90th pctile already
* 95% winsorizing made max change an 80% increase before. now it's 216% and 462% increase at 95th pctile (v similar with weights, slightly less extreme)
su chg_febapr chg_febjun chg_aprjun, d
su chg_febapr chg_febjun chg_aprjun [aw =w7_fwgt], d


** is there increased occ switching up here?
gen occmatch = w6_occu == w7_occu

foreach var in febapr febjun aprjun {
	xtile xt20_`var' = chg_`var' [aw =w7_fwgt], n(20) 
}

*std errors too huge anyway cos tiny cells... but nothing evident
tab xt20_febjun, sum(occmatch)
tab xt20_aprjun, sum(occmatch)





// INCOMES****************************


use "${trash}\temp.dta", clear

** new reweights **
cap drop w6_hhinc_respond agecatnids

gen w6_hhinc_respond = !mi(w6_hhincome_cl)
recode w7_age (0/29 = 1) (30/39 = 2) (40/50 = 3) (50/max = 4) , gen(agecatnids)

logit w6_hhinc_respond i.w7_race i.w7_gender i.agecatnids i.w7_prov urban empapr1 i.w5_hhincomepc_q4

cap drop pscore
predict pscore
cap drop invpw
gen invpw = 1/pscore
su invpw,d		// looks completely ok to me... largest value is 2*median, though is a notable right tail as densities show (looks less dramatic for pscore as opposed to invpw). 
	// kdensity invpw
	// twoway (kdensity invpw if w6_hhinc_respond == 0) (kdensity invpw if w6_hhinc_respond == 1), legend(order(1 "missing w6inc" 2 "has w6inc"))
	// twoway (kdensity pscore if w6_hhinc_respond == 0) (kdensity pscore if w6_hhinc_respond == 1), legend(order(1 "missing w6inc" 2 "has w6inc"))
cap drop incwt
gen incwt = round(w7_fwgt * invpw)

foreach var in w7_hhincome w7_hhincome_imp w7_hhincome_lb w7_hhincome_lb_cl w7_hhincome_noimp_cl w7_hhincome_cl w5_hhincome w6_hhincome w6_hhincome_cl w6_hhincome_imp {
	cap drop ln_`var'
	gen ln_`var' = ln(`var')
	
	cap drop d_`var'
	gen d_`var' = `var' if `var' == 0
	replace d_`var' = 1 if `var' > 0 & !mi(`var')
	
	if substr("`var'",1,2) == "w7" {
		gen pc_`var' = `var'/w7_hhsizer 
		gen lnpc_`var' = ln(pc_`var')
	}
}


lab var ln_w7_hhincome "w7 raw"
lab var ln_w7_hhincome_imp "w7 raw + brackets"
lab var ln_w7_hhincome_lb "w7 raw + brackets + lb"
lab var ln_w7_hhincome_lb_cl "w7 raw + brackets + clean lb"
lab var ln_w7_hhincome_noimp_cl "w7 raw + no outliers"
lab var ln_w7_hhincome_cl "w7 raw + brackets + no outliers"
lab var ln_w6_hhincome_cl "w6 raw + no outliers"
lab var ln_w6_hhincome_imp "w6 raw + no outliers + lb"

 ** OUTLIERS?

* w7: with or without removing outliers? better to remove, probably. reduces variance, brings mean closer to median. unfortunately slightly exaggerates bracket bunching
su w7_hhincome_imp w7_hhincome_cl  [aw=w7_fwgt], d
su w7_hhincome w7_hhincome_noimp_cl  [aw=w7_fwgt], d

twoway ///
	(kdensity ln_w7_hhincome_imp [aw=w7_fwgt], lcolor(blue) lpattern(solid)) ///
	(kdensity ln_w7_hhincome_cl [aw=w7_fwgt], lcolor(blue) lpattern(dash)) ///
	(kdensity ln_w7_hhincome [aw=w7_fwgt], lcolor(red) lpattern(solid)) ///
	(kdensity ln_w7_hhincome_noimp_cl [aw=w7_fwgt], lcolor(red) lpattern(dash))

** BUNCHING: STRAIGHT HH INCOME	
	
twoway ///
	(kdensity ln_w6_hhincome_cl [aw=w7_fwgt], lcolor(red) lpattern(solid)) ///
	(kdensity ln_w7_hhincome_cl [aw=w7_fwgt], lcolor(blue) lpattern(dash)) ///
	(kdensity ln_w7_hhincome_noimp_cl [aw=w7_fwgt], lcolor(blue) lpattern(solid)) ///
	, legend(order(1 "w6 hhincome" 2 "w7 with brackets" 3 "w7 no brackets")) title("hhincome densities (cleaned), no restrictions except balanced panel")
	graph export "${cram_w2}\Figures\extra_diagnostics\hhinc_xsec.png", replace

twoway ///
	(kdensity ln_w6_hhincome_cl [aw=w7_fwgt], lcolor(red) lpattern(solid)) ///
	(kdensity ln_w7_hhincome_cl [aw=w7_fwgt], lcolor(blue) lpattern(dash)) ///
	if !mi(ln_w6_hhincome_cl) & !mi(ln_w7_hhincome_cl) ///
	, legend(order(1 "w6 hhincome" 2 "w7 with brackets")) title("hhincome densities (cleaned), same individuals")
	graph export "${cram_w2}\Figures\extra_diagnostics\hhinc_panel_brac.png", replace

twoway ///
	(kdensity ln_w6_hhincome_cl [aw=w7_fwgt], lcolor(red) lpattern(solid)) ///
	(kdensity ln_w7_hhincome_noimp_cl [aw=w7_fwgt], lcolor(blue) lpattern(solid)) ///
	if !mi(ln_w6_hhincome_cl) & !mi(ln_w7_hhincome_noimp_cl) ///
	, legend(order(1 "w6 hhincome" 2 "w7 no brackets")) title("hhincome densities (cleaned), same individuals")
	graph export "${cram_w2}\Figures\extra_diagnostics\hhinc_panel_nobrac.png", replace

** BUNCHING: PC INCOME

twoway ///
	(kdensity w6_lnhhincomepc [aw=w7_fwgt], lcolor(red) lpattern(solid)) ///
	(kdensity lnpc_w7_hhincome_cl [aw=w7_fwgt], lcolor(blue) lpattern(dash)) ///
	(kdensity lnpc_w7_hhincome_noimp_cl [aw=w7_fwgt], lcolor(blue) lpattern(solid)) ///
	, legend(order(1 "w6 hhincome" 2 "w7 with brackets" 3 "w7 no brackets")) title("hhpc income densities (cleaned), no restrictions except balanced panel") xline(6.078 7.143)
	graph export "${cram_w2}\Figures\extra_diagnostics\pcinc_xsec.png", replace

twoway ///
	(kdensity w6_lnhhincomepc [aw=w7_fwgt], lcolor(red) lpattern(solid)) ///
	(kdensity lnpc_w7_hhincome_cl [aw=w7_fwgt], lcolor(blue) lpattern(dash)) ///
	if !mi(w6_lnhhincomepc) & !mi(lnpc_w7_hhincome_cl) ///
	, legend(order(1 "w6 hhincome" 2 "w7 with brackets")) title("hhpc income densities (cleaned), same individuals") xline(6.078 7.143)
	graph export "${cram_w2}\Figures\extra_diagnostics\pcinc_panel_brac.png", replace

* with hhinc attrition weights
twoway ///
	(kdensity w6_lnhhincomepc [aw=incwt], lcolor(red) lpattern(solid)) ///
	(kdensity lnpc_w7_hhincome_cl [aw=incwt], lcolor(blue) lpattern(dash)) ///
	if !mi(w6_lnhhincomepc) & !mi(lnpc_w7_hhincome_cl) ///
	, legend(order(1 "w6 hhincome" 2 "w7 with brackets")) title("hhpc income densities (cleaned), same individuals") xline(6.078 7.143)
	graph export "${cram_w2}\Figures\extra_diagnostics\pcinc_panel_brac_incwt.png", replace	
	
twoway ///
	(kdensity w6_lnhhincomepc [aw=w7_fwgt], lcolor(red) lpattern(solid)) ///
	(kdensity lnpc_w7_hhincome_noimp_cl [aw=w7_fwgt], lcolor(blue) lpattern(solid)) ///
	if !mi(w6_lnhhincomepc) & !mi(lnpc_w7_hhincome_noimp_cl) ///
	, legend(order(1 "w6 hhincome" 2 "w7 no brackets")) title("hhpc income densities (cleaned), same individuals") xline(6.078 7.143)
	graph export "${cram_w2}\Figures\extra_diagnostics\pcinc_panel_nobrac.png", replace


	* zeros, sample size, mean, median (hhinc and pcinc)

tabstat d_w6_hhincome_cl d_w7_hhincome_cl d_w7_hhincome_noimp_cl w6_hhincome_cl w7_hhincome_cl w7_hhincome_noimp_cl w6_hhincomepc pc_w7_hhincome_cl pc_w7_hhincome_noimp_cl [fw=w7_fwgt], stat(mean p50 count) columns(statistics) varwidth(28) 
	
tabstat d_w6_hhincome_cl d_w7_hhincome_cl d_w7_hhincome_noimp_cl w6_hhincome_cl w7_hhincome_cl w7_hhincome_noimp_cl w6_hhincomepc pc_w7_hhincome_cl pc_w7_hhincome_noimp_cl [fw=w7_fwgt] if !mi(w6_hhincome_cl) & !mi(w7_hhincome_cl), stat(mean p50 count) columns(statistics) varwidth(28) 
	
** with hhinc attrition weights:
tabstat d_w6_hhincome_cl d_w7_hhincome_cl d_w7_hhincome_noimp_cl w6_hhincome_cl w7_hhincome_cl w7_hhincome_noimp_cl w6_hhincomepc pc_w7_hhincome_cl pc_w7_hhincome_noimp_cl [fw=incwt] if !mi(w6_hhincome_cl) & !mi(w7_hhincome_cl), stat(mean p50 count) columns(statistics) varwidth(28) 
	

// MANUAL WORKERS

use "${trash}\temp.dta", clear


tab w6_manual w7_manual [fw=fwgt], m row nofreq
	// only 44% retention...

tab w6_occupcat w7_occupcat [fw=fwgt], m row nofreq
	// much lower manual retention than other cats, substantial shift into service...
	// pretty substantial shifts into missing too, which is weird?
tab w7_occupcat w6_occupcat [fw=fwgt], m row nofreq
	// but quite a lot of shifts FROM retail into manual tooo
	
tab w6_manual [fw=fwgt], m
tab w7_manual [fw=fwgt], m
	// slight decrease in manual on net, but not much



} // pre-checks
	
	
	
	
	
	
	
	
***************************************************************
*CALCULATE MEANS 
***************************************************************


//PROGRAM FOR STATS
cap prog drop t1stats
prog define t1stats
	syntax [if]
	
	foreach mo in feb apr jun {

	*Total emp in each category
	estpost tabstat emp`mo'1 emp`mo'2 emp`mo'3 emp`mo'4 `if' [fw=w7_fwgt], s(n mean)
	forval c= 1/4 {
		mat emp`mo'`c'=e(emp`mo'`c')
	}
	mat t`mo'= (emp`mo'1[1,1], emp`mo'1[1,2], emp`mo'2[1,2], emp`mo'3[1,2], emp`mo'4[1,2])
	
	}

	mat B= (B \ tfeb \ tapr \ tjun)
end 


//HETEROGENEITY CATEGORIES
cap prog drop t1hetcats
prog define t1hetcats
	syntax [if], progname(string)

	//ALL
	`progname'

	//FEMALE AND TERTIARY
	foreach var in female nontertiary {
		foreach i of numlist 1 0 {
			`progname' if `var'==`i' 
		}
	}
	
	//Occup cat and 2017 hhincome cats
	foreach i of numlist 3 2 1 {
		`progname' if w6_occupcat==`i'
	}
	foreach i of numlist 1 2 3 {
		`progname' if w5_hhincomepc_cat==`i'
	}

	//2017 w5_a_em1contr_d
	foreach i of numlist 0 1 {
		`progname' if contract==`i' 
	}
	
	foreach i of numlist 1 0 {
		`progname' if urban==`i' 
	}

end


use  "${trash}\temp.dta", clear
matrix B = J(1,5,.) 
t1hetcats, progname(t1stats)

mat coln B= "freq" "emp" "paidl" "unpaidl" "unemp"
 
 
 

***************************************************************
*EXHIBIT 1
***************************************************************



*EXHIBIT 1A, Overall employment***********************************

use "${trash}\temp.dta", clear

//Reshape for standard errors (ttest doesn't work with svy)
ren (empfeb1 empapr1 empjun1) (emp1 emp2 emp3)
ren (empfeb2 empapr2 empjun2) (paid1 paid2 paid3)
ren (empfeb3 empapr3 empjun3) (unpaid1 unpaid2 unpaid3)
ren (empfeb4 empapr4 empjun4) (unemp1 unemp2 unemp3)
keep pid emp? paid? unpaid? unemp? w7_fwgt cluster stratum 
reshape long emp paid unpaid unemp, i(pid) j(time)
g covid= time==3
g covidapr= time==2
svyset cluster [weight = w7_fwgt], strata(stratum)


//Collect estimates
mat A = J(1,3,.) 
foreach var in emp paid unpaid unemp {
	svy: reg `var' if time==1
	mat t1= (_b[_cons], r(table)[5,1], r(table)[6,1])
	svy: reg `var' if time==2
	mat t2= (_b[_cons], r(table)[5,1], r(table)[6,1])
	svy: reg `var' if time==3
	mat t3= (_b[_cons], r(table)[5,1], r(table)[6,1])
	svy: reg `var' covidapr if inlist(time,1,2)
	mat t4= (_b[covid],  r(table)[5,1], r(table)[6,1])
	svy: reg `var' covid if inlist(time,2,3)
	mat t5= (_b[covid],  r(table)[5,1], r(table)[6,1]) 
	svy: reg `var' covid if inlist(time,1,3)
	mat t6= (_b[covid],  r(table)[5,1], r(table)[6,1]) 
	
	mat A= (A \ t1 \ t2 \ t3 \ t4 \ t5 \ t6)
}
mat A= A[2..., 1...]


clear 
svmat A
g id= _n
ren (A1 A2 A3)(b lb ub)
g emptype= floor((id-1)/6) + 1
g month= mod(id-1,6)+1

*Adjust to percentages
foreach var in b lb ub {
	replace `var'= round(100*`var')
}


*Group by month
sort month emptype
g orderid= _n
*Create gaps for bars
forval i= 4(4)24 {
	replace orderid= orderid+1 if orderid>=`i'+`i'/4
}


twoway (bar b orderid if emptype==1, col($emp1 )) ///
		(bar b orderid if emptype==2, col($emp2 )) ///
		(bar b orderid if emptype==3, col($emp3 )) ///
		(bar b orderid if emptype==4, col($emp4 )) ///
		(rcap ub lb orderid, col(gray%70)) ///
		(scatter b orderid, msym(none) mlab(b) mlabpos(11)), ///
		legend(row(2) order(1 "Active empl. (days>0)" 2 "Paid leave (days=0,wage>0)" 4 "Not employed"  3 "Temp. layoff (days=0, wage=0)") pos(6)) ///
		xlabel( 2.5 `""Pre-Lockdown" "(Feb)""'  7.5 `""Lockdown" "(L5, Apr)""' 12.5 `""Lockdown" "(L3, Jun)""' 17.5 `""Change" "(Feb-Apr)""' 22.5 `""Change" "(Apr-Jun)""' 27.5 `""Change" "(Feb-Jun)""', noticks) ///
		scheme(plotplain) xtitle("Employment status") ytitle("Pct. of working age adults") 
*ysize(6) xsize(5)

graph export "${cram_w2}\Figures\ex1a_empall_v2.pdf", replace
graph export "${cram_w2}\Figures\ex1a_empall_v2.svg", replace





*EXHIBIT 1B: Net Employment hetero se******************************

use "${trash}\temp.dta", clear

ren (w6_empcat_feb w6_empcat_apr w7_empcat_jun w6_manual) (empcat1 empcat2 empcat3 manual)
keep pid empcat? female nontertiary noncontract manual poor urban w5_hhincomepc_cat w7_fwgt cluster stratum black
reshape long empcat, i(pid) j(time)
g covid= time==3
svyset cluster [weight = w7_fwgt], strata(stratum)


forval i=1/3 {
	g emp`i'= empcat<=`i' if empcat!=.
}
 
 
//June vs Feb
eststo clear
foreach dummy in female nontertiary noncontract manual poor black urban {
foreach y in emp1 emp2 emp3 {
	g covid_`dummy'= covid*`dummy'
	svy: reg `y' covid `dummy' covid_`dummy' if `dummy'!=. & inlist(time,1,3)
	nlcom `dummy': (_b[covid]+_b[covid_`dummy'])/(_b[_cons]+_b[`dummy'])-_b[covid]/_b[_cons], post
	estimates store `y'`dummy'
	drop covid_`dummy'
}
}


coefplot (emp1female emp1black emp1poor emp1nontertiary emp1manual emp1noncontract emp1urban,  ciop(lp(shortdash))) ///
	(emp2female emp2black emp2poor emp2nontertiary emp2manual emp2noncontract emp2urban, ciop(lp(longdash))) ///
	(emp3female emp3black emp3poor emp3nontertiary emp3manual emp3noncontract emp3urban, ciop(lp(solid) lw(thick))) ///
	, xline(0)  coeflabels(female= `""Female" "(vs. Male)""' black= `" "Black" "(vs. White)" "' ///
	poor= `""Poorer" "(vs. Richer)""'  nontertiary= `""Non-Tertiary Educ." "(vs. Tertiary)""' ///
	manual= `""Manual Occup." "(vs. Other)""'  noncontract= `" "Informal" "(vs. Formal)" "' urban= `" "Urban" "(vs. Rural)" "') ///
	leg(on order(1 "Active empl. (days>0)" 3 "Any income" 5 "Any job") pos(6) row(1)) ///
	xti("Differential change in employment rate, June vs. Feb", size(small))  
*ysize(6) xsize(5)
graph export "${cram_w2}\Figures\ex1b_emphetse_junfeb_v1.pdf", replace
graph export "${cram_w2}\Figures\ex1b_emphetse_junfeb_v1.svg", replace


//June vs Apr
eststo clear
foreach dummy in female nontertiary noncontract manual poor black urban {
foreach y in emp1 emp2 emp3 {
	g covid_`dummy'= covid*`dummy'
	svy: reg `y' covid `dummy' covid_`dummy' if `dummy'!=. & inlist(time,2,3)
	nlcom `dummy': (_b[covid]+_b[covid_`dummy'])/(_b[_cons]+_b[`dummy'])-_b[covid]/_b[_cons], post
	estimates store `y'`dummy'
	drop covid_`dummy'
}
}


coefplot (emp1female emp1black emp1poor emp1nontertiary emp1manual emp1noncontract emp1urban,  ciop(lp(shortdash))) ///
	(emp2female emp2black emp2poor emp2nontertiary emp2manual emp2noncontract emp2urban, ciop(lp(longdash))) ///
	(emp3female emp3black emp3poor emp3nontertiary emp3manual emp3noncontract emp3urban, ciop(lp(solid) lw(thick))) ///
	, xline(0)  coeflabels(female= `""Female" "(vs. Male)""' black= `" "Black" "(vs. White)" "' ///
	poor= `""Poorer" "(vs. Richer)""'  nontertiary= `""Non-Tertiary Educ." "(vs. Tertiary)""' ///
	manual= `""Manual Occup." "(vs. Other)""'  noncontract= `" "Informal" "(vs. Formal)" "' urban= `" "Urban" "(vs. Rural)" "') ///
	leg(on order(1 "Active empl. (days>0)" 3 "Any income" 5 "Any job") pos(6) row(1)) ///
	xti("Differential change in employment rate, June vs. April", size(small))  
*ysize(6) xsize(5)
graph export "${cram_w2}\Figures\ex1b_emphetse_junapr_v1.pdf", replace
graph export "${cram_w2}\Figures\ex1b_emphetse_junapr_v1.svg", replace




//EXHIBIT 1C, HET EMP BARS**************************************


//Labelling and grouping 
cap prog drop fig1hetcats
prog define fig1hetcats

	*Label bars (groups)
	lab def group 1 "All" 2 "Women" 3 "Men"  4 "Non-Tertiary" 5 "Tertiary" 6 "Manual" 7 "Service/Operators"  8  "Professionals" 9 "Q1-2" 10 "Q3" 11 "Q4" 12 "Informal" 13 "Formal" 14 "Urban" 15 "Rural", modify
	lab val group group

	g supergroup= 1 if inlist(group, 1)
	replace supergroup= 2 if inlist(group, 2,3)
	replace supergroup= 3 if inlist(group, 4,5)
	replace supergroup= 4 if inlist(group, 6,7,8)
	replace supergroup= 5 if inlist(group, 9,10,11)
	replace supergroup= 6 if inlist(group, 12,13)
	replace supergroup= 7 if inlist(group, 14,15)
end



//NET CHANGE, % of employed 

//Prep matrix dataset of estimates
matrix A3a = J(1,3,.) 
matrix A3b = J(1,3,.) 

mat T= B[2..., 1..5]
local numrows=  rowsof(T)	

*Take jun-feb and jun-apr proportions of adults
forval i= 3(3)`numrows' {
	*Jun-feb
	mat t= ((T[`i',3]-T[`i'-2,3])/T[`i'-2,2]) 
	mat t= (t, (T[`i',4]-T[`i'-2,4])/T[`i'-2,2]) 
	mat t= (t, (T[`i',5]-T[`i'-2,5])/T[`i'-2,2]) 
	mat A3a= (A3a \ t)
	
	*Jun-apr (as % of loss in jun-feb)
	mat t= ((T[`i',3]-T[`i'-1,3])/(T[`i'-1,2]-T[`i'-2,2])) 
	mat t= (t, (T[`i',4]-T[`i'-1,4])/(T[`i'-1,2]-T[`i'-2,2])) 
	mat t= (t, (T[`i',5]-T[`i'-1,5])/(T[`i'-1,2]-T[`i'-2,2])) 
	mat A3b= (A3b \ t)
}
mat A3a= A3a[2...,1...]
mat A3a= A3a'
mat A3b= A3b[2...,1...]
mat A3b= A3b'


//Now jun to feb
clear
*xsvmat A3a, names(cols) norestore
svmat A3a, names(cols)

*Define emp cat
g empcat= 2 if _n==1
replace empcat= 3 if _n==2
replace empcat= 4 if _n==3

*Some juggling to get into shape for bar graph
reshape long cols, i(empcat)
ren (_j cols) (group emprate)
reshape wide emprate, i(group) j(empcat)
foreach var in emprate4 emprate3 emprate2 {
	replace `var'= `var'*100
}

fig1hetcats
g furlough= emprate3+emprate2

graph bar (mean)  emprate4 furlough, ///
	stack over(group, label(angle(45) labsize(vsmall))) ///
	over(supergroup,  relabel(1 "All" 2 "Sex" 3 "Education" ///
	4 "Occupation" 5 "HH income (2017)" 6 "Contract (2017)" 7 "Urban") ///
	label(labsize(vsmall))) nofill leg(on pos(6) row(1) ///
	order(1 "Not employed" 2 "Temp. layoff or paid leave (days=0)")) bar(1, color($emp4)) ///
	bar(2, color(pink %70)) ///
	yti("Net active empl. loss (pct of Feb)") ///
	blabel(bar, format(%2.0f) size(small) pos(center))

graph export "${cram_w2}\Figures\ex1c_emphetcat_junfeb_v2.pdf", replace
graph export "${cram_w2}\Figures\ex1c_emphetcat_junfeb_v2.svg", replace






//Now jun to apr
clear
*xsvmat A3b, names(cols) norestore
svmat A3b, names(cols)

*Define emp cat
g empcat= 2 if _n==1
replace empcat= 3 if _n==2
replace empcat= 4 if _n==3

*Some juggling to get into shape for bar graph
reshape long cols, i(empcat)
ren (_j cols) (group emprate)
reshape wide emprate, i(group) j(empcat)
foreach var in emprate4 emprate3 emprate2 {
	replace `var'= `var'*100
}

fig1hetcats

graph bar (mean)  emprate4 emprate3 emprate2, ///
	stack over(group, label(angle(45) labsize(vsmall))) ///
	over(supergroup,  relabel(1 "All" 2 "Sex" 3 "Education" ///
	4 "Occupation" 5 "HH income (2017)" 6 "Contract (2017)" 7 "Urban") ///
	label(labsize(vsmall))) nofill leg(on pos(6) row(1) ///
	order(1 "Not employed" 2 "Temp. layoff (days=0,wage=0)" ///
	3 "Paid leave (days=0,wage>0)")) bar(1, color($emp4)) ///
	bar(2, color($emp3)) bar(3, color($emp2)) ///
	yti("Net active empl. gain (pct of Feb-Apr loss)") ///
	blabel(bar, format(%2.0f) size(small) pos(center))

graph export "${cram_w2}\Figures\ex1c_emphetcat_junapr_v2.pdf", replace
graph export "${cram_w2}\Figures\ex1c_emphetcat_junapr_v2.svg", replace






*EXHIBIT 1 app A, Emp transition******************************

//Jun - feb
use "${trash}\temp.dta", clear

svyset cluster [weight = w7_fwgt], strata(stratum)

mat A1a= J(1,3,.)
foreach j of numlist 1 4 {
forval i=1/4 {
	svy: mean empjun`i' if w6_empcat_feb==`j'
	mat rtable= r(table)
	mat t= (rtable[1,1], rtable[5,1], rtable[6,1])
	mat A1a= (A1a \ t)
}
}
mat A1a= A1a[2..., 1...]


//Clean up
clear 
svmat A1a
g id= _n
ren (A1a1 A1a2 A1a3)(b lb ub)
recode id (1/4=1)(5/8=4), gen(emp_feb)
recode id (1 5= 1)(2 6=2)(3 7=3)(4 8=4), gen(emp_jun)
replace id= id+1 if id>=5

*Adjust to percentages
foreach var in b lb ub {
	replace `var'= round(100*`var')
}


twoway (bar b id if emp_jun==1, col($emp1 )) ///
		(bar b id if emp_jun==2, col($emp2 )) ///
		(bar b id if emp_jun==3, col($emp3 )) ///
		(bar b id if emp_jun==4, col($emp4 )) ///
		(rcap ub lb id, col(gray%70)) ///
		(scatter b id, msym(none) mlab(b) mlabpos(11)), ///
		legend(row(2) order(1 "Active empl. (days>0)" 2 "Paid leave (days=0,wage>0)" 4 "Not employed" 3 "Temp. layoff (days=0, wage=0)") ///
		pos(6) ti("Employment status in June", size(small))) ///
		xlabel( 2.5 "Active empl. (days>0), Feb" 7.5 "Not employed, Feb", noticks) ///
		scheme(plotplain) xtitle("") ytitle("Pct. of employment category")  
*ysize(6) xsize(5)

graph export "${cram_w2}\Figures\AppEx3a_jlossall_junfeb_v1.pdf", replace
graph export "${cram_w2}\Figures\AppEx3a_jlossall_junfeb_v1.svg", replace




//Jun - apr
use "${trash}\temp.dta", clear

svyset cluster [weight = w7_fwgt], strata(stratum)

mat A1a= J(1,3,.)
foreach j of numlist 1 2 3 4 {
forval i=1/4 {
	svy: mean empjun`i' if w6_empcat_apr==`j'
	mat rtable= r(table)
	mat t= (rtable[1,1], rtable[5,1], rtable[6,1])
	mat A1a= (A1a \ t)
}
}
mat A1a= A1a[2..., 1...]


//Clean up
clear 
svmat A1a
g id= _n
ren (A1a1 A1a2 A1a3)(b lb ub)
g emp_apr= floor((id-1)/4)+1
g emp_jun= mod(id-1,4)+1

sort emp_apr emp_jun
g orderid= _n
forval i= 4(4)16 {
	replace orderid= orderid+1 if orderid>=`i'+`i'/4
}

*Adjust to percentages
foreach var in b lb ub {
	replace `var'= round(100*`var')
}


twoway (bar b orderid if emp_jun==1, col($emp1 )) ///
		(bar b orderid if emp_jun==2, col($emp2 )) ///
		(bar b orderid if emp_jun==3, col($emp3 )) ///
		(bar b orderid if emp_jun==4, col($emp4 )) ///
		(rcap ub lb orderid, col(gray%70)) ///
		(scatter b orderid, msym(none) mlab(b) mlabpos(11)), ///
		legend(row(2) order(1 "Active empl. (days>0)" 2 "Paid leave (days=0,wage>0)" 4 "Not employed" 3 "Temp. layoff (days=0, wage=0)") pos(6) ti("Employment status in June", size(small))) ///
		xlabel( 2.5 "Active empl., Apr" 7.5 "Paid leave, Apr" 12.5 "Temp. layoff, Apr" 17.5 "Not employed, Apr", noticks) ///
		scheme(plotplain) xtitle("") ytitle("Pct. of employment category")  
*ysize(6) xsize(5)

graph export "${cram_w2}\Figures\AppEx3a_jlossall_junapr_v2.pdf", replace
graph export "${cram_w2}\Figures\AppEx3a_jlossall_junapr_v2.svg", replace






*EXHIBIT 1 app B: job loser het se********************************


//Jun - Feb
use "${trash}\temp.dta", clear
ren w6_manual manual
svyset cluster [weight = w7_fwgt], strata(stratum)

keep if w6_empcat_feb==1
forval i=1/3 {
	g emp`i'= w7_empcat_jun<=`i' if w7_empcat_jun!=.
}

//Group by hetero cat
foreach dummy in female nontertiary noncontract manual poor black urban {
foreach y in emp1 emp2 emp3 {
	svy: reg `y' `dummy'
	estimates store `y'`dummy'
}
}

coefplot (emp1female emp1black emp1poor emp1nontertiary emp1manual emp1noncontract emp1urban,  ciop(lp(shortdash))) ///
(emp2female emp2black emp2poor emp2nontertiary emp2manual emp2noncontract emp2urban, ciop(lp(longdash))) ///
(emp3female emp3black emp3poor emp3nontertiary emp3manual emp3noncontract emp3urban, ciop(lp(solid) lw(thick))), ///
xline(0)  coeflabels(female= `""Female" "(vs. Male)""' black= `" "Black" "(vs. White)" "' ///
poor= `""Poorer" "(vs. Richer)""'  nontertiary= `""Non-Tertiary Educ." "(vs. Tertiary)""' ///
manual= `""Manual Occup." "(vs. Other)""'  noncontract= `" "Informal" "(vs. Formal)" "' ///
urban= `" "Urban" "(vs. Rural)" "') leg(on order(1 "Active empl. (days>0)" 3 "Any income" 5 "Any job") ///
pos(6) row(1))  xti("Differential Pr(employed) in June if working in Feb", size(small)) drop(_cons)  
*ysize(6) xsize(5)

graph export "${cram_w2}\Figures\AppEx3b_jlosshetse_junfeb_v1.pdf", replace
graph export "${cram_w2}\Figures\AppEx3b_jlosshetse_junfeb_v1.svg", replace



//Jun - apr
use "${trash}\temp.dta", clear
ren w6_manual manual
svyset cluster [weight = w7_fwgt], strata(stratum)

keep if w6_empcat_apr==1
forval i=1/3 {
	g emp`i'= w7_empcat_jun<=`i' if w7_empcat_jun!=.
}

//Group by hetero cat
foreach dummy in female nontertiary noncontract manual poor black urban {
foreach y in emp1 emp2 emp3 {
	svy: reg `y' `dummy'
	estimates store `y'`dummy'
}
}

coefplot (emp1female emp1black emp1poor emp1nontertiary emp1manual emp1noncontract emp1urban,  ciop(lp(shortdash))) ///
(emp2female emp2black emp2poor emp2nontertiary emp2manual emp2noncontract emp2urban, ciop(lp(longdash))) ///
(emp3female emp3black emp3poor emp3nontertiary emp3manual emp3noncontract emp3urban, ciop(lp(solid) lw(thick))), ///
xline(0)  coeflabels(female= `""Female" "(vs. Male)""' black= `" "Black" "(vs. White)" "' ///
poor= `""Poorer" "(vs. Richer)""'  nontertiary= `""Non-Tertiary Educ." "(vs. Tertiary)""' ///
manual= `""Manual Occup." "(vs. Other)""'  noncontract= `" "Informal" "(vs. Formal)" "' ///
urban= `" "Urban" "(vs. Rural)" "') leg(on order(1 "Active empl. (days>0)" 3 "Any income" 5 "Any job") ///
pos(6) row(1))  xti("Differential Pr(employed) in June if working in Apr", size(small)) drop(_cons)  
*ysize(6) xsize(5)

graph export "${cram_w2}\Figures\AppEx3b_jlosshetse_junapr_v1.pdf", replace
graph export "${cram_w2}\Figures\AppEx3b_jlosshetse_junapr_v1.svg", replace





 
*EXHIBIT 1 app C, Emp Het job loser******************************

cap prog drop t1bstats
prog define t1bstats
	syntax [if]

	estpost tabstat empjun2 empjun3 empjun4 [fw=w7_fwgt] `if', s(mean)
	forval c= 2/4 {
		mat empjun`c'=e(empjun`c')
	}
	mat t= (empjun2[1,1], empjun3[1,1], empjun4[1,1])
	mat A4= (A4 \ t)
end 


//Jun to feb
use  "${trash}\temp.dta", clear
matrix A4 = J(1,3,.) 

*Restrict to job losers only!
keep if w6_empcat_feb==1 

*Collect estimates
t1hetcats, progname(t1bstats)

mat A4= A4[2...,1...]
mat A4= A4'

clear
*xsvmat A4, names(cols) norestore
svmat A4, names(cols)

*Define emp cat
g empcat= 2 if _n==1
replace empcat= 3 if _n==2
replace empcat= 4 if _n==3

*Some juggling to get into shape for bar graph
reshape long cols, i(empcat)
ren (_j cols) (group emprate)
reshape wide emprate, i(group) j(empcat)
foreach var in emprate4 emprate3 emprate2 {
	replace `var'= `var'*100
}

fig1hetcats

graph bar (mean)  emprate4 emprate3 emprate2, stack ///
over(group, label(angle(45) labsize(vsmall))) ///
over(supergroup,  relabel(1 "All" 2 "Sex" 3 "Education" ///
4 "Occupation" 5 "HH income (2017)" 6 "Contract (2017)" 7 "Urban") ///
label(labsize(vsmall))) nofill leg(on pos(6) row(1) ///
order(1 "Not employed" 2 "Temp. layoff (days=0,wage=0)" 3 "Paid leave (days=0,wage>0)")) ///
bar(1, color($emp4 )) bar(2, color($emp3 )) bar(3, color($emp2 )) ///
yti("Pct of Feb active empl.") blabel(bar, format(%2.0f) size(small) pos(center))

graph export "${cram_w2}\Figures\AppEx3c_jlosshetse_junfeb_v1.pdf", replace
graph export "${cram_w2}\Figures\AppEx3c_jlosshetse_junfeb_v1.svg", replace







***************************************************************
*EXHIBIT 3: SOCIAL PROTECTION
***************************************************************


//PROGRAM FOR STATS
cap prog drop ex3stats
prog define ex3stats
	syntax [if], mainvar(string)
	
	estpost tabstat `mainvar'1 `mainvar'2 `mainvar'3 `mainvar'4 `if' [fw=w7_fwgt]
	mat t= (e(`mainvar'1)[1,1], e(`mainvar'2)[1,1], e(`mainvar'3)[1,1], e(`mainvar'4)[1,1])

	mat C= (C \ t)
end 



//HETEROGENEITY CATEGORIES
cap prog drop sphet
prog define sphet
	syntax, progname(string) mainvar2(string)

	`progname', mainvar(`mainvar2')
	
	//FEMALE 
	foreach i of numlist 1 0 {
		`progname' if female==`i', mainvar(`mainvar2')
	}

	//OCCUP
	foreach i of numlist 3 2 1 {
		`progname' if w6_occupcat==`i', mainvar(`mainvar2')
	}

	foreach var in earn_feb_conq {
	foreach i of numlist 1 2 3 {
		`progname' if `var'==`i', mainvar(`mainvar2')
	}
	}

	foreach i of numlist 0 1 {
		`progname' if contract==`i' , mainvar(`mainvar2')
	}

	foreach i of numlist 1 0 {
		`progname' if urban==`i' , mainvar(`mainvar2')
	}
end


//Some annoying reshaping for graphs
cap prog drop sp_graph
prog define sp_graph
	g id=_n
	reshape long C, i(id)
	ren (_j C) (group coverage)
	replace coverage= coverage*100

	*Label bars (groups)
	lab def group 1 "All" 2 "Women" 3 "Men" 4 "Manual" 5 "Service/Operators" 6 "Professionals" 7 "Q1-2" 8 "Q3" 9 "Q4" 10 "Informal" 11 "Formal" 12 "Urban" 13 "Rural", modify
	lab val group group

	g supergroup= 1 if inlist(group, 1)
	replace supergroup= 2 if inlist(group, 2,3)
	replace supergroup= 3 if inlist(group, 4,5,6)
	replace supergroup= 4 if inlist(group, 7,8,9)
	replace supergroup= 5 if inlist(group, 10,11)
	replace supergroup= 6 if inlist(group, 12,13)

	reshape wide coverage, i(group) j(id)
end


//EMPLOYED****************************************************
* For employed, do 3 graphs: current, job regainers and joblosers but for covters in apr

//JUNE
use  "${trash}\temp.dta", clear

*Define only for employed in feb and by cat in jun 
tab w7_cover_grnt_ters if w6_empcat_feb==1 & inlist(w7_empcat_jun, 2,3), gen(covters)

*Run stats
mat C= J(1,4,.)
sphet, progname(ex3stats) mainvar2(covters)

*Manipulate as stata dataset, cols are each group (eg men)
mat C= C[2...,1...]
mat C= C'
clear
svmat C
sp_graph

graph bar (mean)  coverage1 coverage2 coverage3 coverage4, ///
stack over(group, label(angle(45) labsize(vsmall))) ///
over(supergroup,  relabel(1 "All" 2 "Sex" 3 "Occupation" ///
4 "Earnings quartile (Feb)" 5 "Contract (2017)" 6 "Urban") ///
label(labsize(vsmall))) nofill leg(on pos(6) row(1) ///
order(1 "No protection" 2 "TERS only" 3 "HH grant only" 4 "Both")) ///
bar(1, color(red%70)) bar(2, color(navy%70)) bar(3, color(purple%70)) ///
bar(4, color(green%70)) yti("% workers on leave by each group") ///
blabel(bar, format(%2.0f) size(small) pos(center))
	
	graph export "${cram_w2}\Figures\ex3a_covters_junfeb_v1.pdf", replace
	
	
	
	

//APRIL JOB LOSER & JUN JOB LOSER, COV TERS IN APR
use  "${trash}\temp.dta", clear

*Define only for employed in feb, job loss i april, job gain in june
tab w6_cover_grnt_ters if w6_empcat_feb==1 & inlist(w6_empcat_apr, 2,3) & inlist(w7_empcat_jun, 2,3), gen(covters)

*Run stats
mat C= J(1,4,.)
sphet, progname(ex3stats) mainvar2(covters)

*Manipulate as stata dataset, cols are each group (eg men)
mat C= C[2...,1...]
mat C= C'
clear
svmat C
sp_graph

graph bar (mean)  coverage1 coverage2 coverage3 coverage4, ///
stack over(group, label(angle(45) labsize(vsmall))) ///
over(supergroup,  relabel(1 "All" 2 "Sex" 3 "Occupation" ///
4 "Earnings quartile (Feb)" 5 "Contract (2017)" 6 "Urban") ///
label(labsize(vsmall))) nofill leg(on pos(6) row(1) ///
order(1 "No protection" 2 "TERS only" 3 "HH grant only" 4 "Both")) ///
bar(1, color(red%70)) bar(2, color(navy%70)) bar(3, color(purple%70)) ///
bar(4, color(green%70)) yti("% workers on leave by each group") ///
blabel(bar, format(%2.0f) size(small) pos(center))
	
	graph export "${cram_w2}\Figures\ex3a_covtersapr_jobloss_v1.pdf", replace

	
	
	
//APRIL JOB LOSER & JUN JOB GAINER, COV TERS IN APR
use  "${trash}\temp.dta", clear

*Define only for employed in feb, job loss i april, job gain in june
tab w6_cover_grnt_ters if w6_empcat_feb==1 & inlist(w6_empcat_apr, 2,3) & w7_empcat_jun==1, gen(covters)

*Run stats
mat C= J(1,4,.)
sphet, progname(ex3stats) mainvar2(covters)

*Manipulate as stata dataset, cols are each group (eg men)
mat C= C[2...,1...]
mat C= C'
clear
svmat C
sp_graph

graph bar (mean)  coverage1 coverage2 coverage3 coverage4, ///
stack over(group, label(angle(45) labsize(vsmall))) ///
over(supergroup,  relabel(1 "All" 2 "Sex" 3 "Occupation" ///
4 "Earnings quartile (Feb)" 5 "Contract (2017)" 6 "Urban") ///
label(labsize(vsmall))) nofill leg(on pos(6) row(1) ///
order(1 "No protection" 2 "TERS only" 3 "HH grant only" 4 "Both")) ///
bar(1, color(red%70)) bar(2, color(navy%70)) bar(3, color(purple%70)) ///
bar(4, color(green%70)) yti("% workers on leave by each group") ///
blabel(bar, format(%2.0f) size(small) pos(center))
	
	graph export "${cram_w2}\Figures\ex3a_covtersapr_jobregain_v1.pdf", replace

	
	
//UNEMPLOYED****************************************************
* For unemployed, do 2 graphs: UIF focus and SRD focus



//UIF FOCUS
use  "${trash}\temp.dta", clear

*3% some missings
tab cover_uif_unemp if w6_empcat_feb==1 & w7_empcat_jun==4, mi

*Define only for employed in feb and by cat in jun 
tab cover_uif_unemp if w6_empcat_feb==1 & w7_empcat_jun==4, gen(covuif)

*Run stats
mat C= J(1,4,.)
sphet, progname(ex3stats) mainvar2(covuif)

*Manipulate as stata dataset, cols are each group (eg men)
mat C= C[2...,1...]
mat C= C'
clear
svmat C
sp_graph

graph bar (mean)  coverage1 coverage2 coverage3 coverage4, ///
stack over(group, label(angle(45) labsize(vsmall))) ///
over(supergroup,  relabel(1 "All" 2 "Sex" 3 "Occupation" ///
4 "Earnings quartile (Feb)" 5 "Contract (2017)" 6 "Urban") ///
label(labsize(vsmall))) nofill leg(on pos(6) row(1) ///
order(1 "No protection" 2 "UIF only" 3 "HH grant only" 4 "Both")) ///
bar(1, color(red%70)) bar(2, color(pink%70)) bar(3, color(purple%70)) ///
bar(4, color(green%70)) yti("% job losers by each group") ///
blabel(bar, format(%2.0f) size(small) pos(center))

graph export "${cram_w2}\Figures\ex3b_covuif_junfeb_v1.pdf", replace
graph export "${cram_w2}\Figures\ex3b_covuif_junfeb_v1.svg", replace



//SRD FOCUS
use  "${trash}\temp.dta", clear

*BEWARE! 10% some missings
tab cover_srd_unemp if w6_empcat_feb==1 & w7_empcat_jun==4, mi

*Define only for employed in feb and by cat in jun 
tab cover_srd_unemp if w6_empcat_feb==1 & w7_empcat_jun==4, gen(covsrd)

*Run stats
mat C= J(1,4,.)
sphet, progname(ex3stats) mainvar2(covsrd)

*Manipulate as stata dataset, cols are each group (eg men)
mat C= C[2...,1...]
mat C= C'
clear
svmat C
sp_graph

graph bar (mean)  coverage1 coverage2 coverage3 coverage4, ///
stack over(group, label(angle(45) labsize(vsmall))) ///
over(supergroup,  relabel(1 "All" 2 "Sex" 3 "Occupation" ///
4 "Earnings quartile (Feb)" 5 "Contract (2017)" 6 "Urban") ///
label(labsize(vsmall))) nofill leg(on pos(6) row(1) ///
order(1 "No protection" 2 "SRD grant only" 3 "Other protection only" 4 "Both")) ///
bar(1, color(red%70)) bar(2, color(pink%70)) bar(3, color(purple%70)) ///
bar(4, color(green%70)) yti("% job losers by each group") ///
blabel(bar, format(%2.0f) size(small) pos(center))

graph export "${cram_w2}\Figures\ex3b_covsrd_junfeb_v1.pdf", replace
graph export "${cram_w2}\Figures\ex3b_covsrd_junfeb_v1.svg", replace




//SRD line graph****************************************************

/*proportion of all adults in each decile, who received SRD, 
proportion of adults in a household, who received SRD, 
proportion of adults who are unemployed and receive no grants, who received SRD.*/

use  "${trash}\temp.dta", clear

xtile w5_hhincomepc_dec= w5_hhincomepc [aw=w7_fwgt], n(10) 
recode w7_ind_inccovid w7_hhsrd (.=0)

g srdeligible= 0
replace srdeligible= 1 if w7_ind_incchld!=1 & w7_ind_incgovpen!=1 & w7_ind_incdis!=1 & (inlist(w6_empcat_apr,3,4) | inlist(w7_empcat_jun,3,4))
*Note a lot of employed in june actually did get the grant

g e_indcovid= w7_ind_inccovid if srdeligible==1

forval i= 1/4 {
	g julcovid`i'= w7_incvgrt==`i' if w7_incvgrt!=.
	g e_julcovid`i'= w7_incvgrt==`i' if srdeligible==1 & w7_incvgrt!=.
}

collapse (mean) w7_ind_inccovid w7_hhsrd e_indcovid *julcovid* [aw=w7_fwgt], by(w5_hhincomepc_dec)

foreach var in w7_ind_inccovid w7_hhsrd e_indcovid e_julcovid1 e_julcovid2 e_julcovid3 e_julcovid4 julcovid1 julcovid2 julcovid3 julcovid4 {
	replace `var'= `var'*100
}

*June
twoway (scatter w7_hhsrd w5_hhincomepc_dec, connect(l) col(navy%70) lp(dash)) (scatter w7_ind_inccovid w5_hhincomepc_dec, connect(l) col(red%70) lp(solid))  (scatter e_indcovid w5_hhincomepc_dec, connect(l) col(green%70) lp(shortdash)), leg(on pos(6) row(1) order(1 "Part of household w/ grant"  2 "Out of all adults" 3 "Out of eligible adults")) yti("Pct. receiving SRD grant") xti("Decile of  household income per capita in 2017 (poorest to richest)")

graph export "${cram_w2}\Figures\ex3c_srdrecipients_Jun_v2.pdf", replace
graph export "${cram_w2}\Figures\ex3c_srdrecipients_Jun_v2.svg", replace
	
	
	
*July
graph bar (mean)  julcovid1 julcovid2 julcovid3 julcovid4, stack over(w5_hhincomepc_dec) leg(on pos(6) row(1) order(1 "Approved" 2 "Pending" 3 "Rejected" 4 "Did not apply")) bar(1, color(green%70)) bar(2, color(purple%70)) bar(3, color(red%70)) bar(4, color(gray)) yti("% Adults") b1ti("Decile of household income per capita (poorest to richest)") blabel(bar, format(%2.0f) size(small) pos(center))

graph export "${cram_w2}\Figures\ex3c_srdrecipients_JulAug_v1.pdf", replace	
graph export "${cram_w2}\Figures\ex3c_srdrecipients_JulAug_v1.svg", replace	

	
*July eligible
graph bar (mean)  e_julcovid1 e_julcovid2 e_julcovid3 e_julcovid4, stack over(w5_hhincomepc_dec) leg(on pos(6) row(1) order(1 "Approved" 2 "Pending" 3 "Rejected" 4 "Did not apply")) bar(1, color(green%70)) bar(2, color(purple%70)) bar(3, color(red%70)) bar(4, color(gray)) yti("% Eligible adults") b1ti("Decile of household income per capita (poorest to richest)") blabel(bar, format(%2.0f) size(small) pos(center))

graph export "${cram_w2}\Figures\ex3c_srdeligible_JulAug_v1.pdf", replace
graph export "${cram_w2}\Figures\ex3c_srdeligible_JulAug_v1.svg", replace
	

***************************************************************
*EXHIBIT 4: WELFARE EFFECTS
***************************************************************

/*
1. Match w/ NIDS vars
2. Use lasso for selection equation
3. Use psmatch2 for reweighting of job loss sample and save weight
4. Save results for
	a. Hunger
	b. Poverty 
	c. Household income density
*/


//Prepare list of cat and continuous vars*********************


//PROGRAMS************************************************

di "STARTING AT `c(current_time)'"

//LASSO
cap prog drop lassopscore
prog define lassopscore
	
	*Check that all own vars have no missings!
	foreach var in contract w7_educ_bins urban {
		replace `var'= 999 if `var'==. | `var'<0
	}
	
	*Run Lasso
	*lasso logit loss w6_age age2 w6_gender i.w6_educ_bins urban contract $vlcategorical $vlcontinuous [iw=w7_fwgt], rseed(42) stopok
	lasso logit loss w6_age age2 w6_gender i.w6_educ_bins urban contract $vlcategorical $vlcontinuous [iw=w7_fwgt], rseed(42) sel(adapt) stop(0.01)
	cap drop pscore
	predict pscore, post

	*Own score 
	cap drop psweight
	sum loss [aw=w7_fwgt]  if pscore!=.
	local aveloss= r(mean)
	g psweight= pscore/(1-pscore)*(1-`aveloss')/`aveloss'*w7_fwgt if loss==0
	replace psweight= w7_fwgt if loss==1
	sum pscore if loss==1, de
	replace psweight= . if (pscore<r(p1) | pscore>r(p99))

end





//Main plot for poverty
cap prog drop povestimates
prog define povestimates
	syntax, i(integer) matname(string)
forval p= 5.8(0.2)7.8 {
	g pov= w7_hhincomepc<exp(`p') if w7_hhincomepc!=.
	svy: reg pov loss
	mat t3= (`i', `p',3, _b[loss]) 
	mat `matname' = (`matname' \ t3)
	drop pov
}
end




//APPENDIX POV GRAPHS
cap prog drop dflpovestimates
program define dflpovestimates

syntax, mat(string)

mat `mat' = J(1,4,.) 

foreach var in w7_foodpov w7_ubpov foodpov_nosrd ubpov_nosrd {
	svy: reg `var' if loss==1
	mat t1= (1, _b[_cons], r(table)[5,1], r(table)[6,1])
	svy: reg `var' if loss==0 
	mat t2= (2, _b[_cons], r(table)[5,1], r(table)[6,1])
	svy: reg `var' loss
	mat t3= (3, _b[loss],  r(table)[5,1], r(table)[6,1]) 
	mat `mat'  = (`mat'  \ t1 \ t2 \ t3)
}
mat `mat' = `mat'[2..., 1...]


//let's make sure we have the right structure in mind here:
assert rowsof(`mat') == 12

mat `mat'b= `mat'[1..12,1...]
svy: mean w5_hhdependents if loss==1
mat t= (.,r(table)[1,1],.,.)
mat `mat'b= (`mat'b \ t)
mat coln `mat'b= "Loss?" "b" "lb" "ub"
mat rown `mat'b= "Food" "Food" "Food" "ub" "ub" "ub" "Food w/o g" "Food w/o g" "Food w/o g" "ub w/o g" "ub w/o g" "ub w/o g"
end





//PANELS A AND B: JOB LOSS******************************
*Only empcat 1 --> 3 or 4 (not 2)

use  "${trash}\temp.dta", clear
*Decide on which job loss var to use
cap drop loss
g loss= w7_jobloss_34

keep if w6_empcat_feb==1 & (loss==1 | inlist(w7_empcat_jun, 1))
merge 1:1 pid using "${cram}\Data\temp_lasso2.dta", keep(master match)
*All match!

//Need to restore macros
vl rebuild


//Run lasso (convergence issues...)
// lassopscore
// global lassovars `e(allvars_sel)'

/*
*WORKAROUND: USE PREVIOUS VARS (see below)
*/

	* taking lassovars from "Also to check lasso: lassocoef and lassogof" below
	global lassovars "w6_educ_bins LS_hlser LS_mthdth_con LS_fthtert LS_grcur LS_lv94prov LS_bhlive LS_bhlive_n LS_em1occ_isco_c LS_em1cheqlm LS_em1dedtax LS_emssll LS_emsprofloss LS_emctype_isco_c LS_unemdc LS_hltb_bf LS_hlbp_med LS_dtveh_joint LS_assell LS_h_ownpaid LS_h_ownlandright LS_h_fdsoypay LS_h_nfclthm LS_h_negstc LS_h_agrlnd_a LS_h_agcrgrntom LS_h_agcwmlk LS_h_intlng1 LS_best_race LS_timediv LS_em1inc LS_em1pay LS_em1hrs LS_em1dedmed_a LS_em1deduif_a LS_cgmnv1 LS_h_fdmarprd LS_h_nfpapspn LS_h_nfcelspn LS_h_nfnetspn LS_h_nftoysspn LS_best_edu LS_zhfa LS_zbmi LS_fwag LS_help LS_chld LS_f_deb_i LS_hhgovt"


	logit loss $lassovars
	cap drop pscore
	predict pscore

	*Own score 
	cap drop psweight
	sum loss [aw=w7_fwgt]  if pscore!=.
	local aveloss= r(mean)
	g psweight= pscore/(1-pscore)*(1-`aveloss')/`aveloss'*w7_fwgt if loss==0
	replace psweight= w7_fwgt if loss==1
	sum pscore if loss==1, de
	replace psweight= . if (pscore<r(p1) | pscore>r(p99))

	
ren (pscore psweight) (jobpscore jobpsweight) 
save  "${trash}\temp2.dta", replace


//Also save these estimates bc takes long to run
keep pid jobpscore jobpsweight 
save  "${cram_w2}\Data\jobpscores_v1.dta", replace		

di "ENDING AT `c(current_time)'"


/*If just want to run graphs:
use  "${trash}\temp.dta", clear
merge 1:1 pid using "${cram_w2}\Data\jobpscores_v1.dta", keep(match) nogen
g loss= w7_jobloss_34
save "${trash}\temp2.dta", replace

*Also to check lasso: lassocoef and lassogof
global lassovars "w6_educ_bins LS_hlser LS_mthdth_con LS_fthtert LS_grcur LS_lv94prov LS_bhlive LS_bhlive_n LS_em1occ_isco_c LS_em1cheqlm LS_em1dedtax LS_emssll LS_emsprofloss LS_emctype_isco_c LS_unemdc LS_hltb_bf LS_hlbp_med LS_dtveh_joint LS_assell LS_h_ownpaid LS_h_ownlandright LS_h_fdsoypay LS_h_nfclthm LS_h_negstc LS_h_agrlnd_a LS_h_agcrgrntom LS_h_agcwmlk LS_h_intlng1 LS_best_race LS_timediv LS_em1inc LS_em1pay LS_em1hrs LS_em1dedmed_a LS_em1deduif_a LS_cgmnv1 LS_h_fdmarprd LS_h_nfpapspn LS_h_nfcelspn LS_h_nfnetspn LS_h_nftoysspn LS_best_edu LS_zhfa LS_zbmi LS_fwag LS_help LS_chld LS_f_deb_i LS_hhgovt"
*/


//HHINCOME
use "${trash}\temp2.dta", clear

twoway (kdensity w7_lnhhincomepc [aw= jobpsweight] if loss==1, lp(solid) ) ///
	(kdensity w7_lnhhincomepc [aw= jobpsweight] if loss==0, lp(dash) ) ///
	(kdensity w7_lnhhincomepc [aw= w7_fwgt] if loss==0, lp(shortdash) ) ///
	/*(kdensity w6_lnhhincomepc [aw= jobpsweight] if loss==1, lp(solid) lc(blue %70))*/ ///
	/*(kdensity w6_lnhhincomepc [aw= jobpsweight] if loss==0, lp(dash) lc(blue %70))*/ ///
	/*(kdensity w6_lnhhincomepc [aw= w7_fwgt] if loss==0, lp(shortdash) lc(blue %70))*/ , ///
	leg(on row(2) pos(6) order(1 "Job losers, June" 2 "Job retainers, June (re-weighted)" 3 "Job retainers, June" ///
	/*4 "Job losers, Apr" 5 "Job retainers, Apr (re-weighted)" 6 "Job retainers, Apr" */ )) ///
	yti(Density) xti("log Household income per capita (June)") xline(6.078 7.143)

graph export "${cram_w2}\Figures\ex5a_jlosshhinc_v1.pdf", replace
graph export "${cram_w2}\Figures\ex5a_jlosshhinc_v1.svg", replace


//POVERTY LINES

//Clean sample
use  "${trash}\temp.dta", clear
cap drop loss
g loss= w7_jobloss_34
keep if w6_empcat_feb==1 & (loss==1 | inlist(w7_empcat_jun, 1))
merge 1:1 pid using "${cram}\Data\temp_lasso2.dta", keep(master match)
keep cluster stratum loss w7_hhincomepc $lassovars w7_fwgt
save "${trash}\temp3.dta", replace


//Bootstrap! Keep to 100 for now
mat D0 = J(1,4,.) 
forval i=1/100 {
	use "${trash}\temp3.dta", replace
	bsample, strata(loss)

	logit loss $lassovars
	cap drop pscore
	predict pscore, p

	cap drop psweight
	sum loss [aw=w7_fwgt] if pscore!=.
	local aveloss= r(mean)
	g psweight= pscore/(1-pscore)*(1-`aveloss')/`aveloss'*w7_fwgt if loss==0
	replace psweight= w7_fwgt if loss==1
	sum pscore if loss==1, de
	replace psweight= . if (pscore<r(p1) | pscore>r(p99))

	keep cluster psweight stratum loss w7_hhincomepc
	svyset cluster [weight = psweight], strata(stratum) singleunit(scaled)
	qui povestimates, i(`i') matname(D0)
}

//Number of job losers
use  "${trash}\temp2.dta", clear
svyset cluster [weight = jobpsweight], strata(stratum) singleunit(scaled)

forval p= 5.8(0.2)7.8 {
	g pov= w7_hhincomepc<exp(`p') if w7_hhincomepc!=.
	svy: reg pov if loss==1
	mat t1= (0, `p', 1, _b[_cons])
	svy: reg pov if loss==0
	mat t2= (0, `p',2, _b[_cons])
	mat D0 = (D0 \ t1 \ t2)
	cap drop pov
}

total w7_fwgt if loss==1
local loss: di %3.2f r(table)[1,1]/1e6
local noloss 
total w7_fwgt if loss==0
local noloss : di %3.2f r(table)[1,1]/1e6


//Plot!
clear 
svmat D0
ren(D01 D02 D03 D04)(bsnum povline esttype povrate)
replace povrate= povrate*100
bys esttype povline: egen mpovrate= mean(povrate)
count if povline==6
local ubtail= round(r(N)*.975)
local lbtail= round(r(N)*.025)
bys esttype povline (povrate): g ub=povrate[`ubtail']
bys esttype povline (povrate): g lb=povrate[`lbtail']	
keep if bsnum==1 | bsnum==0

sort povline
twoway (scatter mpovrate povline if esttype==1, connect(l) lp(longdash)) ///
	(scatter mpovrate povline if esttype==2, connect(l) lp(shortdash)) ///
	(scatter mpovrate povline if esttype==3, connect(l) lp(solid) lw(thick)) ///
	(rarea lb ub povline if esttype==3, sort fc(gray%30)), ///
	legend(row(1) order(1 "Job losers (`loss' million)" ///
	2 "Job retainers (`noloss' million - re-weighted)" 3 "Difference") pos(6)) ///
	yti("Poverty rate") xline(6.078 7.143) yscale(range(0 100)) ylabel(0(20)100) ///
	xtitle("Poverty line (log of household income per capita)")
	
graph export "${cram_w2}\Figures\ex5b_jlosspov_junfeb_v1.pdf", replace
graph export "${cram_w2}\Figures\ex5b_jlosspov_junfeb_v1.svg", replace

*For ref: 6=33.5%, 7= 23%

	
	
	
	
//Appendix plots for poverty
use "${trash}\temp2.dta", clear
svyset cluster [weight = jobpsweight], strata(stratum) singleunit(scaled)


//Store totals
total w7_fwgt if loss==1
local loss: di %3.2f r(table)[1,1]/1e6
local noloss 
total w7_fwgt if loss==0
local noloss : di %3.2f r(table)[1,1]/1e6


//Run estimates
dflpovestimates, mat(D1)
mat list D1b

/*
*Take 2020 - 2017 for each pov estimate 
bys loss (y): g bdiff= b[_n]-b[_n+1]
replace bdiff= b if y==1

twoway  (bar bdiff orderid if loss==1, col($emp4 )) ///
		(bar bdiff orderid if loss==2, col($emp1 )) ///
		(bar bdiff orderid if loss==3, col(pink%50 )) ///
		(scatter bdiff orderid, msym(none) mlab(bdiff) mlabpos(11)) ///
		if inlist(y,1,2,4), ///
		legend(row(1) order(1 "Job losers (`loss' million)" 2 "Job retainers (`noloss' million - re-weighted)" 3 "Difference") pos(6)) ///
		xlabel(2 "Could not afford food" 6 "$1.90 a day (PPP)" 10 "Upper poverty line (DiD)", noticks) ///
		scheme(plotplain) xtitle("Welfare measure") ytitle("Pct. in poverty") yscale(range(0 60)) ylabel(0(20)60) 
		
graph export "${cram}\Figures\AppEx5a_jlossMDiD_v5.pdf", replace
*/


	

//DIAGNOSTICS
//Overlap of propensity score
use "${trash}\temp2.dta", clear
	egen psbin= cut(jobpscore), at(0(.05)1)
	drop if psbin==.
	g treated= 1 if loss==1 & jobpsweight!=.
	replace treated= 2 if loss==1 & jobpsweight==. 
	replace treated= 0 if loss==0 & jobpsweight!=.
	replace treated= -1 if loss==0 & jobpsweight==.
	collapse (count) freq=pid (mean) loss, by(psbin treated)
	bys psbin loss: egen fullfreq= total(freq)
	bys psbin loss: g freqtag= _n==1
	replace freq=-freq if treated<1 
	replace fullfreq=-fullfreq if treated<1 	
	twoway  (bar freq psbin if treated==1, barw(.05) fc(gray%70)) (bar fullfreq psbin if loss==1 & freqtag==1, barw(.05) fc(none) lp(dash)) (bar freq psbin if treated==0, barw(.05) fc(gray%30)) (bar fullfreq psbin if loss==0 & freqtag==1, barw(.05) fc(none) lp(dash)), leg(row(1) pos(6) order(1 "Job loss sample" 3 "No job loss - comparison sample")) yti("Number of observations") xtitle("Probability of job loss (propensity score)")
	
	graph export "${cram_w2}\Figures\ex4a_jlosspscore_junfeb_v1.pdf", replace
	graph export "${cram_w2}\Figures\ex4a_jlosspscore_junfeb_v1.svg", replace

	

// w5 placebo income figure

use "${trash}\temp2.dta", clear

cap drop jobpscore jobpsweight

global placebovars w6_educ_bins LS_hlser LS_mthdth_con LS_fthtert LS_grcur LS_lv94prov LS_bhlive LS_bhlive_n LS_em1occ_isco_c LS_em1cheqlm LS_em1dedtax LS_emssll LS_emsprofloss LS_emctype_isco_c LS_unemdc LS_hltb_bf LS_hlbp_med LS_dtveh_joint LS_assell LS_h_ownpaid LS_h_ownlandright LS_h_fdsoypay LS_h_nfclthm LS_h_negstc LS_h_agrlnd_a LS_h_agcrgrntom LS_h_agcwmlk LS_h_intlng1 LS_best_race LS_timediv LS_em1inc LS_em1pay LS_em1hrs LS_em1dedmed_a LS_em1deduif_a LS_emhearn_v LS_cgmnv1 LS_h_fdmarprd LS_h_nfpapspn LS_h_nfcelspn LS_h_nfnetspn LS_h_nftoysspn LS_best_edu LS_zhfa LS_zbmi LS_fwag LS_chld LS_f_deb_i


	logit loss $placebovars
	cap drop pscore
	predict pscore

	*Own score 
	cap drop psweight
	sum loss [aw=w7_fwgt]  if pscore!=.
	local aveloss= r(mean)
	g psweight= pscore/(1-pscore)*(1-`aveloss')/`aveloss'*w7_fwgt if loss==0
	replace psweight= w7_fwgt if loss==1
	sum pscore if loss==1, de
	replace psweight= . if (pscore<r(p1) | pscore>r(p99))
	
ren (pscore psweight) (jobrob_pscore jobrob_psweight) 

*Now run (from here for preloaded)
cap g lnw5_hhincomepc= ln(w5_hhincomepc )

twoway (kdensity lnw5_hhincomepc [aw= jobrob_psweight] if loss==1, lp(solid)) (kdensity lnw5_hhincomepc [aw= jobrob_psweight] if loss==0, lp(longdash)) (kdensity lnw5_hhincomepc [aw= w6_wgt] if loss==0, lp(shortdash)), leg(on row(1) pos(6) order(1 "Job losers" 2 "Job retainers (re-weighted)" 3 "Job retainers")) yti(Density) xti("log Household income per capita (2017)") xline(6.078 7.143)

graph export "${cram_w2}\Figures\ex4b_w5jlossinctest.pdf", replace
graph export "${cram_w2}\Figures\ex4b_w5jlossinctest.svg", replace

	


***************************************************************
*AGG POV
***************************************************************

/*
-- Same group: overall poverty in june, poverty in april, difference. 
-- Then: poverty in june without SRD, poverty in april, difference.
-- Restrict to target population of SRD: poverty in june without SRD, poverty as is, poverty in april, difference.

*/	

use "$trash\temp.dta", clear
keep if !mi(w6_hhincomepc) & !mi(w7_hhincomepc)

g srdeligible= 0
replace srdeligible= 1 if w7_ind_incchld!=1 & w7_ind_incgovpen!=1 & w7_ind_incdis!=1 & (inlist(w6_empcat_apr,3,4) | inlist(w7_empcat_jun,3,4))


//Convert to panel: time, hhincomepc, w7_hhincomepc_nosrd, SRD target pop
ren (w6_hhincomepc w7_hhincomepc w7_hhincomepc_nosrd) (hhinc1 hhinc2 hhinc_nosrd2)
g hhinc_nosrd1= hhinc1
keep pid hhinc? hhinc_nosrd? incwt srdeligible cluster stratum 
reshape long hhinc hhinc_nosrd, i(pid) j(time)


g covid= time==1
svyset cluster [weight = incwt], strata(stratum)
save "$trash\temp2.dta", replace




//Overall Poverty
use "$trash\temp2.dta", clear
mat aggpov=  J(1,6,.)
forval p= 5.8(0.2)7.8 {
	cap drop pov*
	g pov= hhinc<exp(`p') 
	
	svy: reg pov if time==1
	mat t1= (_b[_cons])
	svy: reg pov if time==2
	mat t2= (_b[_cons])
	svy: reg pov covid
	mat t3= (_b[covid], r(table)[5,1], r(table)[6,1])  

	mat t= (`p',t1,t2,t3)
	mat aggpov= (aggpov \ t)
}
mat aggpov= aggpov[2..., 1...]

clear 
svmat aggpov
g id= _n
ren (aggpov1 aggpov2 aggpov3 aggpov4 aggpov5 aggpov6)(pline apr jun diff lb ub)
foreach var in apr jun diff lb ub {
	replace `var'= round(100*`var',.001)
}
sort pline

gen perc_change = (diff/apr)*100
list


twoway (scatter apr pline, connect(l) lp(longdash) col(red%70)) (scatter jun pline, connect(l) lp(shortdash) col(red%70)) (scatter diff pline, connect(l) lp(solid) lw(thick) yaxis(2) col(green%70)) (rarea lb ub pline, sort fc(gray%30) lc(gray%0) yaxis(2)), legend(row(1) order(1 "April rate" 2 "June rate" 3 "Difference") pos(6)) yti("Poverty rate", axis(1) col(red%70)) ytitle("Poverty rate reduction", axis(2) col(green%70)) xline(6.078 7.143) xtitle("Poverty line (log of household income per capita)")
	
graph export "${cram_w2}\Figures\ex6_aggpov_junfeb_v2.pdf", replace
graph export "${cram_w2}\Figures\ex6_aggpov_junfeb_v2.svg", replace






//poverty in june without SRD, poverty in april, difference.
use "$trash\temp2.dta", clear

mat aggpov=  J(1,8,.)
forval p= 5.8(0.2)7.8 {
	cap drop pov*
	g pov= hhinc<exp(`p') 
	g pov2= hhinc_nosrd<exp(`p') 
	
	svy: reg pov if time==1
	mat t1= (_b[_cons])
	svy: reg pov if time==2
	mat t2= (_b[_cons])
	svy: reg pov2 if time==2
	mat t3= (_b[_cons])
	svy: reg pov2 covid 
	mat t4= (_b[covid])  
	svy: reg pov covid 
	mat t5= (_b[covid],  r(table)[5,1], r(table)[6,1])  

	mat t= (`p',t1,t2,t3,t4,t5)
	mat aggpov= (aggpov \ t)
}
mat aggpov= aggpov[2..., 1...]

clear 
svmat aggpov
ren (aggpov1 aggpov2 aggpov3 aggpov4 aggpov5 aggpov6 aggpov7 aggpov8)(pline apr jun jun_nosrd diff_nosrd diff lb ub)
foreach var in apr jun jun_nosrd diff_nosrd diff lb ub {
	replace `var'= round(100*`var',.001)
}

sort pline
twoway (scatter apr pline, connect(l) lp(longdash) col(red%70)) ///
(scatter jun pline, connect(l) lp(shortdash) col(red%70)) ///
(scatter jun_nosrd pline, connect(l) lp(shortdash) col(blue%70)) ///
(scatter diff pline, connect(l) lp(solid) lw(thick) col(red%70) yaxis(2)) ///
(rarea lb ub pline, sort fc(gray%30) lc(gray%0) yaxis(2)) ///
(scatter diff_nosrd pline, connect(l) lp(solid) col(blue%70) yaxis(2)), ///
legend(row(1) order(1 "April" 2 "June" 3 "June (no SRD CF)" 4 "Difference" 6 "Difference (no SRD CF)") pos(6)) yti("Poverty rate", axis(1)) ytitle("Poverty rate reduction", axis(2)) xline(6.078 7.143) xtitle("Poverty line (log of household income per capita)")

graph export "${cram_w2}\Figures\ex6_nosrdpov_junfeb_v2.pdf", replace
graph export "${cram_w2}\Figures\ex6_nosrdpov_junfeb_v2.svg", replace

	
	
//Restrict to target population of SRD: poverty in june without SRD, poverty as is, poverty in april, difference 1-2, diff 2-3
use "$trash\temp2.dta", clear
keep if srdeligible==1		
mat aggpov=  J(1,8,.)
forval p= 5.8(0.2)7.8 {
	cap drop pov*
	g pov= hhinc<exp(`p') 
	g pov2= hhinc_nosrd<exp(`p') 
	
	svy: reg pov if time==1
	mat t1= (_b[_cons])
	svy: reg pov if time==2
	mat t2= (_b[_cons])
	svy: reg pov2 if time==2
	mat t3= (_b[_cons])
	svy: reg pov2 covid 
	mat t4= (_b[covid])  
	svy: reg pov covid 
	mat t5= (_b[covid],  r(table)[5,1], r(table)[6,1])  

	mat t= (`p',t1,t2,t3,t4,t5)
	mat aggpov= (aggpov \ t)
}
mat aggpov= aggpov[2..., 1...]

clear 
svmat aggpov
ren (aggpov1 aggpov2 aggpov3 aggpov4 aggpov5 aggpov6 aggpov7 aggpov8)(pline apr jun jun_nosrd diff_nosrd diff lb ub)
foreach var in apr jun jun_nosrd diff_nosrd diff lb ub {
	replace `var'= round(100*`var',.001)
}

sort pline
twoway (scatter apr pline, connect(l) lp(longdash) col(red%70)) ///
(scatter jun pline, connect(l) lp(shortdash) col(red%70)) ///
(scatter jun_nosrd pline, connect(l) lp(shortdash) col(blue%70)) ///
(scatter diff pline, connect(l) lp(solid) lw(thick) col(red%70) yaxis(2)) ///
(rarea lb ub pline, sort fc(gray%30) lc(gray%0) yaxis(2)) ///
(scatter diff_nosrd pline, connect(l) lp(solid) col(blue%70) yaxis(2)), ///
legend(row(1) order(1 "April" 2 "June" 3 "June (no SRD CF)" 4 "Difference" 6 "Difference (no SRD CF)") pos(6)) yti("Poverty rate", axis(1)) ytitle("Poverty rate reduction", axis(2)) xline(6.078 7.143) xtitle("Poverty line (log of household income per capita)")

graph export "${cram_w2}\Figures\ex6_unemppov_junfeb_v2.pdf", replace
graph export "${cram_w2}\Figures\ex6_unemppov_junfeb_v2.svg", replace

	



***************************************************************
*END
***************************************************************
