/*MAIN CLEANING FILE
-- Cleans and prepares wave 2 of CRAM + merges all Wave 2 files together along with deflating
-- Note: to use the file with CRAM Wave 1, will need to merge this to the w5_nc file after running the cleaning file for that.
-- Defines earnings, employment 
*/


if c(username)=="ronak" {
	clear all
	global cram_w2  "C:\Users\ronak\Desktop\cram_w2"  // "C:\Users\ronak\Dropbox (Harvard University)\CRAM paper\"
	global trash "C:\Users\ronak\Desktop\cram_w2\"
	global cram "C:\Users\ronak\Dropbox\CRAM paper"
}
if c(username)=="ihsaa" {
	clear all
	global cram_w2  "C:\Users\ihsaa\Dropbox\CRAM paper\Wave 2"  
	global trash "C:\Users\ihsaa\Documents\Data"
	global cram "C:\Users\ihsaa\Dropbox\CRAM paper"
}
if c(username)=="joshb" {
	clear all
	global cram_w2  "C:\Users\joshb\Dropbox\projects\CRAM paper\Wave 2"  
	global trash "C:\Users\joshb\Desktop\inbox"
	global cram "C:\Users\joshb\Dropbox\projects\CRAM paper"
}


********************************************************************
*LINK FILES
********************************************************************


use "${cram_w2}\Data\NIDS-CRAM_Wave2_Anon_V1.0.0.dta", clear
merge 1:1 pid using "${cram_w2}\Data\Link_File_NIDS-CRAM_Wave2_Anon_V1.0.0.dta", 
drop if _merge==2 
drop _merge
merge 1:1 pid using "${cram_w2}\Data\derived_NIDS-CRAM_Wave2_Anon_V1.0.0.dta", 
drop if _merge==2
drop _merge

*adding deflator
scalar base=115.2 												//Set scalar to base month, currently Feb 2020
cap drop w2_nc_deflator
gen w2_nc_deflator=.
replace w2_nc_deflator=base/116.4       // July 2020


lab var w2_nc_deflator "NIDS-CRAM W2 deflator"

rename w2_nc_* w7_*
g fwgt= round(w7_pweight)
numlabel, add

//Get rid of refusal and don't know
foreach var in w7_eminc_june w7_eminc_june_brac w7_emwkinc_june w7_emwkinc_june_brac w7_emdayinc_june w7_em2wksinc_june w7_em2wksinc_june_brac w7_emsinc_june w7_emsinc_june_brac w7_emdays_june {
	recode `var' (-9/-1=.)
}

// fix for the nids-cram derived employment variable (because we're still using v1.0.0 just to avoid extra mess). we don't use this variable, but just in case...
replace w7_empl_stat=0 if w7_em_june==3
	

********************************************************************************
*** Earnings
********************************************************************************

* bracket vars check for updated data:
foreach var in w7_eminc_june_brac w7_emwkinc_june_brac w7_em2wksinc_june_brac w7_emsinc_june_brac    {
	assert inlist(`var', 1,2,3,4,5,6,.)
}

//June EARNINGS 
	*Also need to convert all figures to a monthly figure
	
// Monthly earnings 
	local mbrac1 ERROR
	local mbrac2 1,3000
	local mbrac3 3001,6000
	local mbrac4 6001,12000
	local mbrac5 12001,24000
	local mbrac6 ERROR
	local mbracend 24000
	
	g w7_eminc_jun_imp= w7_eminc_june
	replace w7_eminc_jun_imp = 0 if w7_eminc_june_brac ==1
	forval i = 2/5 {
		qui: su w7_eminc_june if inrange(w7_eminc_june, `mbrac`i''), d
		replace w7_eminc_jun_imp = r(p50) if w7_eminc_june_brac == `i'
	}
	replace w7_eminc_jun_imp = 2*`mbracend' if w7_eminc_june_brac ==6
	
	
// Weekly earnings 
	local wbrac1 ERROR
	local wbrac2 1,700
	local wbrac3 701,1400
	local wbrac4 1401,2800
	local wbrac5 2801,5500
	local wbrac6 ERROR
	local wbracend 5500

	g w7_emwkinc_jun_imp= w7_emwkinc_june
	replace w7_emwkinc_jun_imp = 0 if w7_emwkinc_june_brac ==1
	forval i = 2/5 {
		qui: su w7_emwkinc_june if inrange(w7_emwkinc_june, `wbrac`i''), d
		replace w7_emwkinc_jun_imp = r(p50) if w7_emwkinc_june_brac == `i'
	}
	replace w7_emwkinc_jun_imp = 2*`wbracend' if w7_emwkinc_june_brac ==6
	
	
// Fortnightly earnings 
	local fbrac1 ERROR
	local fbrac2 1,1400
	local fbrac3 1401,2800
	local fbrac4 2801,5500
	local fbrac5 5501,11000
	local fbrac6 ERROR
	local fbracend 11000
	
	g w7_em2wksinc_jun_imp= w7_em2wksinc_june
	replace w7_em2wksinc_jun_imp = 0 if w7_em2wksinc_june_brac ==1
	forval i = 2/5 {
		qui: su w7_em2wksinc_june if inrange(w7_em2wksinc_june, `fbrac`i''), d
		replace w7_em2wksinc_jun_imp = r(p50) if w7_em2wksinc_june_brac == `i'
	}
	replace w7_em2wksinc_jun_imp = 2*`fbracend' if w7_em2wksinc_june_brac ==6
	

//Convert all earnings to monthly 
	* Multipling up to monthly totals. Just check whether the frequency var works as a flag for this replacement:
	assert mi(w7_eminc_june) if inlist(w7_empay_freq,1,2,3)	
	assert w7_empay_freq == 1 if !mi(w7_emdayinc_june)
	assert w7_empay_freq == 2 if !mi(w7_emwkinc_june)
	assert w7_empay_freq == 3 if !mi(w7_em2wksinc_june)	// all good
	
	* just to confirm that we shouldn't be using embusdays_apr for daily wage, confirm that those who report self-emp or "run a business" do not report daily earnings:
	assert mi(w7_emdayinc_june) if inlist(w7_emtyp, 3,4)
	
	gen temp_day_monthly = w7_emdayinc_jun*w7_emdays_jun*4.33 if w7_emdays_jun >= 0 
		// none report zero days so don't have the problem we had in w1 of some workers reporting daily earnings but no days
	gen temp_wk_monthly = w7_emwkinc_jun_imp*4.33
	gen temp_2wks_monthly = w7_em2wksinc_jun_imp*2.17
		
	* Sub in imputed daily, weekly and 2-weekly earnings
	replace w7_eminc_jun_imp = temp_day_monthly if mi(w7_eminc_jun_imp)
	replace w7_eminc_jun_imp = temp_wk_monthly if mi(w7_eminc_jun_imp)
	replace w7_eminc_jun_imp = temp_2wks_monthly if mi(w7_eminc_jun_imp)
	

	drop temp_day_monthly temp_wk_monthly temp_2wks_monthly

	
//June profits 
	g w7_emsinc_jun_imp= w7_emsinc_june 
	replace w7_emsinc_jun_imp = 0 if w7_emsinc_june_brac ==1
	
	sum w7_emsinc_june if w7_emsinc_june >0 & w7_emsinc_june <3000, d
	replace w7_emsinc_jun_imp = r(p50) if w7_emsinc_june_brac ==2
	sum w7_emsinc_june if w7_emsinc_june >=3000 & w7_emsinc_june<=6000, d
	replace w7_emsinc_jun_imp = r(p50) if w7_emsinc_june_brac ==3
	sum w7_emsinc_june if w7_emsinc_june >6000 & w7_emsinc_june<=12000, d
	replace w7_emsinc_jun_imp = r(p50) if w7_emsinc_june_brac ==4
	sum w7_emsinc_june if w7_emsinc_june>12000 & w7_emsinc_june<=24000, d
	replace w7_emsinc_jun_imp = r(p50) if w7_emsinc_june_brac ==5	
	replace w7_emsinc_jun_imp = 2*24000 if w7_emsinc_june_brac ==6
	
	
//June totwage
	egen w7_totwage_jun = rsum(w7_emsinc_jun_imp w7_eminc_jun_imp), missing
	replace w7_totwage_jun =. if w7_totwage_jun >100000 


********************************************************************************
*** Employment status
********************************************************************************

//Clean up days var
g w7_emdays_jun_imp= w7_emdays_june
//just confirm that it only exists for self-employed and business owners
assert mi( w7_embusdays_june) if !inlist(w7_emtyp,3,4)

replace w7_emdays_jun_imp= w7_embusdays_june if w7_emdays_jun_imp==. & w7_embusdays_june>=0

//edited Label

lab def w7_empcat 1 `""Working": days>0"' 2 `""Paid leave": days=0,wage>0"' 3 `""Unpaid leave": emp/emreturn,days=0,wage=0"' 4 `""Not employed": noemp,days=0,wage=0"', modify

//Doing the same as for feb and april (prioritize comparibility)
foreach mo in jun {
	
	*some checks before we get going
	assert w7_emdays_`mo'_imp >= 0
	assert w7_totwage_`mo' >= 0
	
	cap drop w7_empcat_`mo'
	g w7_empcat_`mo'= .
	
	*1 - days>0
	replace w7_empcat_`mo'= 1 if (w7_emdays_`mo'_imp>0 & w7_emdays_`mo'_imp!=.)
	
	*2 - days==0, wage>0
	replace w7_empcat_`mo'= 2 if (w7_emdays_`mo'_imp==0 | w7_emdays_`mo'_imp==.) ///
	& (w7_totwage_`mo'>0 & w7_totwage_`mo'!=.)
	
	*3 - emp, days==0, wage==0 ;; also 49 obs "no i'm emp", wage==0, hr==0
	replace w7_empcat_`mo'= 3 if (w7_em_`mo'==1 | w7_emany_`mo'==1 | w7_ems_`mo'==1) ///
	& (w7_emdays_`mo'_imp==0 | w7_emdays_`mo'_imp==.)  ///
	& (w7_totwage_`mo'==0 | w7_totwage_`mo'==.)
	
	replace w7_empcat_`mo'= 3 if (w7_em_`mo' ==2 & w7_emany_`mo'==2 & w7_ems_`mo' == 2) ///
	& (w7_emdays_`mo'_imp==0 | w7_emdays_`mo'_imp==.) ///
	& (w7_totwage_`mo'==0 | w7_totwage_`mo'==.)
	
	*4 - unemp, wage==0, days==0
	replace w7_empcat_`mo'= 4 if (w7_em_`mo'==2 & w7_emany_`mo'==2 & w7_ems_`mo'==3) ///
	& (w7_emdays_`mo'_imp==0 | w7_emdays_`mo'_imp==.) ///
	& (w7_totwage_`mo'==0 | w7_totwage_`mo'==.)
	
	lab val w7_empcat_`mo' w7_empcat
}


*Specific adjustment: Those who earn daily wage in april and say emp but no days. Assign cat 2.
replace w7_empcat_jun= 2 if (w7_em_june==1 | w7_emany_june==1 | w7_ems_june==1) & (w7_emdays_june==.) & (w7_emdayinc_june !=.)

*Specific adjustment: Set emp==3 if return job + reason=lockdown broadly (no wage, no hrs) 
* restrict changes to when w7_empcat_jun==4 or w7_empcat_jun==., and expanding w7_emabs_june reasons (excludes "studying" and "poor health", "retrenched" and "maternity leave") 
replace w7_empcat_jun= 3 if inlist(w7_emabs_june,1,2,4,5,6) & w7_emreturn==1 & inlist(w7_empcat_jun, 4,.)

* set June pensioners to category 4 as NEA. means we have empcat for almost everyone, also logically consistent
replace w7_empcat_jun = 4 if w7_em_june == 3 



********************************************************************************
*** HH income
********************************************************************************


recode w7_hhinc (-9/-1 = .)
rename w7_hhinc w7_hhincome

	local fbrac1 1,1500
	local fbrac2 1501,3000
	local fbrac3 3001,5000
	local fbracend 5000
	
	g w7_hhincome_imp= w7_hhincome
	forval i = 1/3 {
		su w7_hhincome if inrange(w7_hhincome, `fbrac`i''), d
		replace w7_hhincome_imp = r(p50) if w7_hhinc_brac == `i'
	}
	replace w7_hhincome_imp = 2*`fbracend' if w7_hhinc_brac ==4
	



********************************************************************************
*** Deflating (RJ: still needs to be done post merging)
********************************************************************************

*** NIDS-CRAM.  
foreach var in w7_hhincome_imp w7_hhincome w7_totwage_jun w7_eminc_june w7_eminc_jun_imp w7_emsinc_june w7_emsinc_jun_imp w7_emwkinc_june  w7_em2wksinc_june  w7_emdayinc_june {
	replace `var' = `var'*w7_deflator
}



*===============================================================================
***	Cleaning and harmonising variables between NIDS and NIDS-CRAM W1 and W2 
*===============================================================================

*** Age
	rename w7_best_age_yrs w7_age
	recode w7_age (-9/-1=.)

*** Gender
	ren w7_best_gen w7_gender
	
*** Race 
	rename w7_best_race w7_race
	recode w7_race  (-8/-1=.)
	
*** Area
	recode w7_geo2011 (-8/-1=.)
	assert w7_geo2011 >= 0	
	drop w7_area
	clonevar w7_area = w7_geo2011  
	
*** Province
	recode w7_prov2011 (-9/-1=.) (10=.)
	assert w7_prov2011 >= 0
	drop w7_prov
	rename w7_prov2011 w7_prov
	
*** Household composition	
	rename w7_nopres w7_hhsizer 
	replace w7_hhsizer = . if w7_hhsizer ==0 
	rename w7_nou7res w7_tot_child_7
	rename w7_nou18res w7_tot_child
	rename w7_no60res w7_tot_elder
	
	recode w7_hhsizer w7_tot_child w7_tot_child_7 w7_tot_elder w7_nocld w7_nopres_conf (-9/-1=.)
	
	gen w7_tot_adult = w7_hhsizer-(w7_tot_elder+w7_tot_child)
	gen w7_childrenelders = w7_tot_elder+w7_tot_child
			
	*Replace with confirmed number if conflicting
	egen tempsize= rowtotal(w7_tot_child w7_tot_elder w7_nocld)
	replace w7_hhsizer= w7_nopres_conf if tempsize!=w7_hhsizer & w7_outcome==1 & w7_nopres_conf!=.
	drop tempsize
		
*** Education 
assert w7_edschgrd != 20

gen w7_educ_bins = .
replace w7_educ_bins = 1 if inrange(w7_edschgrd, 0, 7) |  w7_edschgrd==19
replace w7_educ_bins = 2 if inrange(w7_edschgrd, 8, 11) | inlist( w7_edschgrd, 13,14,16,17)
replace w7_educ_bins = 3 if inlist(w7_edschgrd, 12,15,18)
replace w7_educ_bins = 4 if w7_edter== 1 & inlist(w7_edschgrd, 12,15,18)
	
la de educ_bins 1 "Up to Primary" 2 "Up to Secondary" 3 "Matric" 4 "Tertiary", modify
lab val w7_educ_bins educ_bins

***Occupation 
	
	* Wave 7*	
	recode w7_emwrk_isco_c w7_emswrk_isco_c w7_unemwrk_isco_c (-9/-1 = .)
	gen w7_occu = .
	
	replace w7_occu = w7_emwrk_isco_c 
	
	replace w7_occu = w7_emswrk_isco_c if mi(w7_occu)
	
	assert mi(w7_emwrk_isco_c) & mi(w7_emswrk_isco_c) if !mi(w7_unemwrk_isco_c)
	replace w7_occu = w7_unemwrk_isco_c if mi(w7_occu)
    
	label val w7_occu w2_nc_occ_code
		
*** Type of work
	recode w7_emtyp (-9/-1=.)	



******************************************************************
*FURTHER CLEANING 
******************************************************************
	
* Careful to make these changes AFTER employment variables defined
	recode w7_emhrs_june (-9/-1 = .) (19/24 = .)  
	recode w7_emdays_june (-9/-1 = .) (8/max = .)  
	gen w7_emhrswk_june = w7_emhrs_june*w7_emdays_june
	lab var w7_emhrswk_june "Average work week (Hours)"

*** July/Aug COVID grant application 
	recode w7_incvgrt (-8/-3 =.)

***	Written contract / formal employment
	recode w7_emcontr (1=1 "Yes") (2=0 "No") (-9/-2=.), gen(w7_formal)	
	lab var w7_formal "Written employment agreement"
	
***Payment frequency 
	recode w7_empay_freq (-8=.)	
	
*** TERS/UIF
	*Note: The NIDS variable related to whether UIF is deducted from one's salary. This is a different concept to the CRAM question, which asks about relief through UIF.
	recode w7_eminc_ters (-9/-8=.) (1=1 "Yes") (2=0 "No") (3=3 "Waiting"), gen(w7_tersuif)
	assert w7_tersuif >= 0
	recode w7_emsteers_june (-9/-8=.) (1=1 "Yes") (2=0 "No") (3=3 "Waiting") (4=4 "Ineligible") (5=5 "Don't know how to") (6=6 "Other support")  , gen(w7_emsters_jun)
	assert w7_emsters_jun >= 0


	recode w7_unemincuifany_june (1=1 "Yes") (2=0 "No") (-9/-8 = .), gen(w7_rwtbenuif_yn)
	assert w7_rwtbenuif_yn >= 0
	lab var w7_rwtbenuif_yn "UIF reduced work-time benefit, juneil"

*** CSG
	 rename w7_hhincchld w7_csg_number 
	 recode w7_csg_number (-9/-3 = .) 
	 assert w7_csg_number >=0 & w7_csg_number < 20 if !mi(w7_csg_number)
	 replace w7_csg_number = 1 if w7_csg_number ==. & w7_incchld == 1  
	 
***	OAPs in household
	rename w7_hhincgovpen w7_oap_number
	recode w7_oap_number (-9/-3 = .)  
	replace w7_oap_number = 1 if w7_oap_number ==. & w7_incgovpen== 1 
	 

*** SRD in household	
	rename w7_hhinccv_june  w7_srd_number
	replace w7_srd_number = 1 if w7_srd_number == -7	
	recode w7_srd_number (-9/-3 = .)  
	  	
***	Personal grant reciept - CRAM
	
	 recode w7_incgov_june (-9/-8=.) (1=1) (2=0)
	 label define w7_incgov 0 "No" 1 "Yes"
	 label val w7_incgov_june w7_incgov
	 recode w7_incgovtyp1 (-9/-8=.)
	 
*adapted code acc to questionnaire changes 	 
tab w7_incgovtyp1, gen(indgrnt)
 
*Numbering thrown off bc of skips. Labels kept and checked.
rename indgrnt1 w7_ind_incchld 
rename indgrnt2 w7_ind_incgovpen  
rename indgrnt3 w7_ind_incdis
rename indgrnt4 w7_ind_incfos 
rename indgrnt5 w7_ind_inccare  
rename indgrnt6 w7_ind_incwar	
rename indgrnt7 w7_ind_inccovid  
rename indgrnt9 w7_ind_incaid
rename indgrnt10 w7_ind_incnsfas 

drop indgrnt8
	 
forval i = 2/4 {	 
	replace w7_ind_incchld = 1  if w7_incgovtyp`i' == 1
	replace w7_ind_incgovpen = 1  if w7_incgovtyp`i' == 2
	replace w7_ind_incdis = 1 if w7_incgovtyp`i' == 3
	replace w7_ind_incfos = 1  if w7_incgovtyp`i' == 4
	replace w7_ind_inccare = 1  if w7_incgovtyp`i' == 5
	replace w7_ind_incwar = 1	 if w7_incgovtyp`i' == 7
	replace w7_ind_inccovid = 1  if w7_incgovtyp`i' == 8
	replace w7_ind_incaid = 1 if w7_incgovtyp`i' == 10
	replace w7_ind_incnsfas = 1  if w7_incgovtyp`i' == 11
}


//Replace oap, csg and srd if individual receives but hh doesn't 
replace w7_csg_number = 1 if (w7_csg_number==. | w7_csg_number==0) & w7_ind_incchld==1  
replace w7_oap_number = 1 if (w7_oap_number ==. | w7_oap_number==0) & w7_ind_incgovpen== 1 
replace w7_srd_number = 1 if (w7_srd_number ==. | w7_srd_number==0) & w7_ind_inccovid== 1 


*** Food 
	recode w7_hhfdyn (-9/-1=.) (1=1) (2=0)  

**GRANT coverage (added SRD grant)
*** Create household grant receipt ***
gen w7_hhincgov = .
replace w7_hhincgov = 1 if w7_csg_number > 0 & !mi(w7_csg_number)
replace w7_hhincgov = 1 if w7_oap_number > 0 & !mi(w7_oap_number)
replace w7_hhincgov = 1 if w7_srd_number > 0 & !mi(w7_srd_number)
replace w7_hhincgov = 1 if w7_incgov_june == 1
replace w7_hhincgov = 0 if w7_incgov_june == 0 & w7_csg_number == 0 & w7_oap_number == 0 & w7_srd_number==0
lab var w7_hhincgov "Grant receipt in household"



//Updated for SRD vs other grants
g w7_hhsrd= 0 if w7_srd_number==0 
replace w7_hhsrd=1 if (w7_srd_number > 0 & !mi(w7_srd_number))



g w7_hhothergrant= 0 if w7_hhincgov!=.
replace w7_hhothergrant= 1 if (w7_oap_number > 0 & !mi(w7_oap_number)) | (w7_csg_number > 0 & !mi(w7_csg_number)) | (w7_incgov_june==1 & w7_ind_inccovid!=1)

gen cover_grnt_unemp = .
replace cover_grnt_unemp = 1 if w7_hhsrd == 0 & w7_hhothergrant == 0
replace cover_grnt_unemp = 2 if w7_hhsrd == 1 & w7_hhothergrant == 0
replace cover_grnt_unemp = 3 if w7_hhsrd == 0 & w7_hhothergrant == 1
replace cover_grnt_unemp = 4 if w7_hhsrd == 1 & w7_hhothergrant == 1

label define cover_grnt_unemp 1 "No cover" 2 "HH SRD only" 3 "HH other Grant only" 4 "Both", modify
lab val cover_grnt_unemp  cover_grnt_unemp 
lab var cover_grnt_unemp "Coverage of grants"

*Do uif version
gen cover_uif_unemp = .
replace cover_uif_unemp = 1 if w7_rwtbenuif_yn!=1 & w7_hhincgov == 0
replace cover_uif_unemp = 2 if w7_rwtbenuif_yn== 1 & w7_hhincgov == 0
replace cover_uif_unemp = 3 if w7_rwtbenuif_yn!= 1 & w7_hhincgov == 1
replace cover_uif_unemp = 4 if w7_rwtbenuif_yn== 1 & w7_hhincgov == 1


label define cover_uif_unemp 1 "No cover" 2 "UIF only" 3 "HH Grant only" 4 "Both", modify
lab val cover_uif_unemp  cover_uif_unemp 
lab var cover_uif_unemp "Coverage of grants"


*Do SRD version
gen cover_srd_unemp = .
replace cover_srd_unemp = 1 if w7_hhsrd == 0 & w7_hhothergrant == 0 & w7_rwtbenuif_yn!=1
replace cover_srd_unemp = 2 if w7_hhsrd == 1 & w7_hhothergrant == 0 & w7_rwtbenuif_yn!=1
replace cover_srd_unemp = 3 if w7_hhsrd == 0 & (w7_hhothergrant == 1 | w7_rwtbenuif_yn==1)
replace cover_srd_unemp = 4 if w7_hhsrd == 1 & (w7_hhothergrant == 1 | w7_rwtbenuif_yn==1)


label define cover_srd_unemp 1 "No cover" 2 "HH SRD only" 3 "HH other protection only" 4 "Both", modify
lab val cover_srd_unemp  cover_srd_unemp 
lab var cover_srd_unemp "Coverage of grants"




*Do SRD version (July-Aug)
g srd_jul= (w7_incvgrt == 1)

gen cover_indsrd_unemp = .
replace cover_indsrd_unemp = 1 if srd_jul == 0 & w7_hhothergrant == 0 & w7_rwtbenuif_yn!=1
replace cover_indsrd_unemp = 2 if srd_jul == 1 & w7_hhothergrant == 0 & w7_rwtbenuif_yn!=1
replace cover_indsrd_unemp = 3 if srd_jul == 0 & (w7_hhothergrant == 1 | w7_rwtbenuif_yn==1)
replace cover_indsrd_unemp = 4 if srd_jul == 1 & (w7_hhothergrant == 1 | w7_rwtbenuif_yn==1)

label define cover_indsrd_unemp 1 "No cover" 2 "Indiv SRD only" 3 "HH other protection only" 4 "Both", modify
lab val cover_indsrd_unemp  cover_indsrd_unemp 



*TERS
gen cover_grnt_ters = .
replace cover_grnt_ters = 1 if w7_tersuif == 0 & w7_incgov_june == 0
replace cover_grnt_ters = 2 if w7_tersuif == 1 & w7_incgov_june == 0
replace cover_grnt_ters = 3 if w7_tersuif == 0 & w7_incgov_june == 1
replace cover_grnt_ters = 4 if w7_tersuif == 1 & w7_incgov_june == 1

label define cover_grnt_ters 1 "No cover" 2 "TERS only" 3 "Ind grant only" 4 "Both", replace
lab val cover_grnt_ters cover_grnt_ters
lab var cover_grnt_ters "Coverage of grants and TERS"




***** Income losses
* Change in main source of income 
recode w7_hhincchng (-9/-1=.) 
recode w7_hhincchng (2=1 "Decreased") (1/3=0 "No"), gen(w7_hhincloss_main)

//Hunger (missing num days goes missing)
recode w7_fdcyn w7_fdcskp w7_fdayn w7_fdaskp (-9/-1=.)
recode  w7_fdcyn w7_fdayn (2=0)

g w7_fdcyn_imp= w7_fdcyn
replace w7_fdcyn_imp= w7_fdcskp/5 if w7_fdcyn_imp==1

g w7_fdayn_imp= w7_fdayn 
replace w7_fdayn_imp= w7_fdaskp/5 if w7_fdayn_imp==1 & w7_fdaskp>0



*******************************************************************************
//Cleaned HH income var
// 1. Income lower bound
*===============================================================================



*cleaning tot grants per hh - reducing number of grants where total number of grants exceeds total number of eligible recipients in hh
// Note: This is not necessarily a correction which reduces noise: People are just as likely to misreport the number of elderly/children as they are to misreport the number of CSGs/OAPs
*csg
count if w7_csg_number > w7_tot_child
gen w7_csg_number_clean = w7_csg_number
replace w7_csg_number_clean = w7_tot_child if w7_csg_number > w7_tot_child & w7_csg_number !=.	
*oap
count if w7_oap_number > w7_tot_elder 
gen w7_oap_number_clean = w7_oap_number
replace w7_oap_number_clean = w7_tot_elder if w7_oap_number > w7_tot_elder & w7_oap_number !=.	

*lower bounds for income = grants in the household + reported labour earnings + personal grant receipt
// First, create these income items
gen w7_csg_inc = w7_csg_number*440+500
gen w7_oap_inc = w7_oap_number*2110
gen w7_csg_inc_cl = w7_csg_number_clean*440+500
gen w7_oap_inc_cl = w7_oap_number_clean*2110
gen w7_dg_inc = 2110 if w7_ind_incdis == 1
gen w7_fcg_inc = 1330 if w7_ind_incfos == 1
gen w7_cdg_inc = 2110 if w7_ind_inccare == 1
//gen w7_srdg_inc = 350 if w7_ind_inccovid ==1 
gen w7_srdg_inc = 350*w7_srd_number

// Second, sum these into a hh_inc lower bound 
*Original hh level csg and oap vars
egen w7_hhincome_lb =     rsum(w7_csg_inc    w7_oap_inc    w7_dg_inc w7_fcg_inc w7_cdg_inc w7_srdg_inc  w7_totwage_jun), missing

*Cleaned hh level csg and oap vars
egen w7_hhincome_lb_cl =  rsum(w7_csg_inc_cl w7_oap_inc_cl w7_dg_inc w7_fcg_inc w7_cdg_inc  w7_srdg_inc w7_totwage_jun), missing

	
// 2. Outlier detection 
*===============================================================================
	
	// Using bacon (https://journals.sagepub.com/doi/pdf/10.1177/1536867X1001000302) to detect outliers in multivariate data, what I do here is predict an income/earnings value based on simple OLS, and then use bacon to determine whether observed values should be considered outliers, given the fitted value for income/earnings. The key parameter we as researchers need to determine, somewhat arbitrarily, is the "percentile" value. This is "the 1 − # percentile of the chi-squared distribution to be used as a threshold to separate outliers from nonoutliers" where a "larger # identifies a larger proportion of the sample as outliers.". Note that the p# I select is different for income than for earnings, which I determined after looking at the scatter plots which identify outliers. We can change this depending on what seems reasonable. 
	// Note: Still need to decide what to do about these outliers - probably the simplest and most sensible approach is to simply trim them. 

	gen w7_hhincome_ln = log(w7_hhincome_imp)
	gen w7_hhincome_noimp_ln = log(w7_hhincome)
	gen w7_hhincome_lb_ln = log(w7_hhincome_lb)
	gen w7_eminc_jun_imp_ln = log(w7_eminc_jun_imp)	
	
* WITH IMP (brackets)
******************

//removed repeats, w7_hhincome_lb, w7_hhsizer and included interactions 
	cap drop w7_hhincome_hat
	reg w7_hhincome_ln w7_age w7_hhsizer i.w7_race i.w7_geo2011 i.w7_occu i.w7_educ_bins i.w7_gender i.w7_prov [aw=fwgt], r 
	predict w7_hhincome_hat	

	cap drop out_hhinc
	bacon w7_hhincome_ln w7_hhincome_hat, generate(out_hhinc) percentile(0.15) replace
	*scatter w7_hhincome_ln w7_hhincome_hat, ml(out_hhinc) ms(i) note("0 = nonoutlier, 1 = outlier")
	*tw (kdensity w7_hhincome_ln  if out_hhinc ==0 [aw=fwgt] ) (kdensity w7_hhincome_ln [aw=fwgt] ), leg(on order(1 "No outliers" 2 "Raw") pos(6) row(1))	//makes quite a bit of difference in density 

	* there was a mistake here, fixed	
	gen w7_hhincome_cl = w7_hhincome_imp if w7_outcome==1
	replace w7_hhincome_cl = . if out_hhinc ==1 & w7_outcome==1  
	
	
* WITHOUT IMP (brackets)
******************

//removed repeats, w7_hhincome_lb, w7_hhsizer and included interactions 
	cap drop w7_hhincome_noimp_hat
	reg w7_hhincome_noimp_ln w7_age w7_hhsizer i.w7_race i.w7_geo2011 i.w7_occu i.w7_educ_bins i.w7_gender i.w7_prov [aw=fwgt], r 
	predict w7_hhincome_noimp_hat	

	cap drop out_hhinc_noimp
	bacon w7_hhincome_noimp_ln w7_hhincome_noimp_hat, generate(out_hhinc_noimp) percentile(0.15) replace
	*scatter w7_hhincome_noimp_ln w7_hhincome_noimp_hat, ml(out_hhinc_noimp) ms(i) note("0 = nonoutlier, 1 = outlier")
	*tw (kdensity w7_hhincome_noimp_ln  if out_hhinc_noimp ==0 [aw=fwgt] ) (kdensity w7_hhincome_noimp_ln [aw=fwgt] ), leg(on order(1 "No outliers" 2 "Raw") pos(6) row(1))	//makes quite a bit of difference in density 

	gen w7_hhincome_noimp_cl = w7_hhincome if w7_outcome==1
	replace w7_hhincome_noimp_cl = . if out_hhinc_noimp ==1 & w7_outcome==1 // 51 outliers 

	
***	Earnings	
	cap drop w7_eminc_jun_imp_hat
	reg w7_eminc_jun_imp_ln w7_age i.w7_race i.w7_geo2011 i.w7_occu i.w7_educ_bins i.w7_gender i.w7_prov if w7_empl_stat ==3 [aw=fwgt], r
	predict w7_eminc_jun_imp_hat	

	cap drop out_eminc
	bacon w7_eminc_jun_imp_ln w7_eminc_jun_imp_hat, generate(out_eminc) percentile(0.15) replace 
	*scatter w7_eminc_jun_imp_ln w7_eminc_jun_imp_hat if w7_empl_stat ==3 , ml(out_eminc) ms(i) note("0 = nonoutlier, 1 = outlier")
	*tw (kdensity w7_eminc_jun_imp_ln  if out_eminc ==0 [aw=fwgt] ) (kdensity w7_eminc_jun_imp_ln [aw=fwgt] ), leg(on order(1 "No outliers" 2 "Raw") pos(6) row(1))	//doesn't make much difference
		// still no difference here so justified to keep ignoring


* The income variables we're interested in
*===============================================================================		

lab var w7_hhincome "raw"
lab var w7_hhincome_imp "raw + brackets"
lab var w7_hhincome_lb "raw + brackets + lb"
lab var w7_hhincome_lb_cl "raw + brackets + clean lb"
lab var w7_hhincome_noimp_cl "raw + no outliers"
lab var w7_hhincome_cl "raw + brackets + no outliers"
	

	
*===============================================================================
***	END
*===============================================================================
